@@ -395,14 +395,19 @@ MsRun::getMsRunXicExtractorInterfaceSp()
         settings.value("global/xic_extractor", "pwiz").toString();
       if(xic_extraction_method == "pwiz")
         {
+          pappso::MsRunXicExtractorFactory::getInstance()
+            .setMsRunXicExtractorFactoryType(
+              pappso::MsRunXicExtractorFactoryType::direct);
           _xic_extractor_sp = pappso::MsRunXicExtractorFactory::getInstance()
                                 .buildMsRunXicExtractorSp(_msrun_reader_sp);
         }
       else
         {
-          _xic_extractor_sp =
-            pappso::MsRunXicExtractorFactory::getInstance()
-              .buildMsRunXicExtractorDiskBufferSp(_msrun_reader_sp);
+          pappso::MsRunXicExtractorFactory::getInstance()
+            .setMsRunXicExtractorFactoryType(
+              pappso::MsRunXicExtractorFactoryType::diskbuffer);
+          _xic_extractor_sp = pappso::MsRunXicExtractorFactory::getInstance()
+                                .buildMsRunXicExtractorSp(_msrun_reader_sp);
         }
       //_xic_extractor_sp = pappso::MsRunXicExtractorFactory::getInstance()
       //                      .buildMsRunXicExtractorDiskBufferSp(*this);
@@ -506,3 +511,210 @@ MsRun::setAlignmentGroup(MsRunAlignmentGroupSp new_group)
 {
   msp_alignmentGroup = new_group;
 }
+
+
+pappso::MassSpectrumCstSPtr
+MsRun::getMassSpectrumCstSPtrByScanNumber(std::size_t scan_number)
+{
+
+  qDebug() << "scan=" << scan_number;
+  if(getMzFormat() == pappso::MzFormat::MGF)
+    {
+      scan_number = scan_number - 1;
+      qDebug() << "MGF format";
+    }
+  pappso::MsRunReaderSPtr msrun_reader_sp = getMsRunReaderSPtr();
+
+  if(msrun_reader_sp == nullptr)
+    {
+      msrun_reader_sp = findMsRunFile();
+      if(msrun_reader_sp == nullptr)
+        {
+          throw pappso::ExceptionNotFound(
+            QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+        }
+    }
+  qDebug();
+  msrun_reader_sp = getMsRunReaderSPtr();
+  if(msrun_reader_sp == nullptr)
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+    }
+
+
+  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__  <<
+  // _ms_run_sp.get()->getMsRunReaderSp().get()->getSpectrumListSize();
+
+  std::size_t spectrum_index = scan_number;
+
+  if(msrun_reader_sp.get()->hasScanNumbers())
+    {
+      qDebug() << "HAS SCAN NUMBERS";
+      spectrum_index =
+        msrun_reader_sp.get()->scanNumber2SpectrumIndex(scan_number);
+    }
+
+  qDebug() << " spectrum file="
+           << msrun_reader_sp.get()->getMsRunId().get()->getFileName()
+           << " index=" << spectrum_index;
+  pappso::MassSpectrumCstSPtr spectrum_sp =
+    msrun_reader_sp.get()->massSpectrumCstSPtr(spectrum_index);
+  qDebug();
+  return spectrum_sp;
+}
+
+pappso::QualifiedMassSpectrum
+MsRun::getQualifiedMassSpectrumByScanNumber(std::size_t scan_number, bool data)
+{
+
+  qDebug() << "scan=" << scan_number;
+  if(getMzFormat() == pappso::MzFormat::MGF)
+    {
+      scan_number = scan_number - 1;
+      qDebug() << "MGF format";
+    }
+  pappso::MsRunReaderSPtr msrun_reader_sp = getMsRunReaderSPtr();
+
+  if(msrun_reader_sp == nullptr)
+    {
+      msrun_reader_sp = findMsRunFile();
+      if(msrun_reader_sp == nullptr)
+        {
+          throw pappso::ExceptionNotFound(
+            QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+        }
+    }
+  qDebug();
+  msrun_reader_sp = getMsRunReaderSPtr();
+  if(msrun_reader_sp == nullptr)
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+    }
+
+
+  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__  <<
+  // _ms_run_sp.get()->getMsRunReaderSp().get()->getSpectrumListSize();
+
+  std::size_t spectrum_index = scan_number;
+
+  if(msrun_reader_sp.get()->hasScanNumbers())
+    {
+      qDebug() << "HAS SCAN NUMBERS";
+      spectrum_index =
+        msrun_reader_sp.get()->scanNumber2SpectrumIndex(scan_number);
+    }
+
+  qDebug() << " spectrum file="
+           << msrun_reader_sp.get()->getMsRunId().get()->getFileName()
+           << " index=" << spectrum_index;
+  return msrun_reader_sp.get()->qualifiedMassSpectrum(spectrum_index, data);
+}
+
+
+pappso::MassSpectrumCstSPtr
+MsRun::getMassSpectrumCstSPtrBySpectrumIndex(std::size_t spectrum_index)
+{
+
+  pappso::MsRunReaderSPtr msrun_reader_sp = getMsRunReaderSPtr();
+
+  if(msrun_reader_sp == nullptr)
+    {
+      msrun_reader_sp = findMsRunFile();
+      if(msrun_reader_sp == nullptr)
+        {
+          throw pappso::ExceptionNotFound(
+            QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+        }
+    }
+  qDebug();
+  msrun_reader_sp = getMsRunReaderSPtr();
+  if(msrun_reader_sp == nullptr)
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+    }
+
+  qDebug() << " spectrum file="
+           << msrun_reader_sp.get()->getMsRunId().get()->getFileName()
+           << " index=" << spectrum_index;
+  pappso::MassSpectrumCstSPtr spectrum_sp =
+    msrun_reader_sp.get()->massSpectrumCstSPtr(spectrum_index);
+  qDebug();
+  return spectrum_sp;
+}
+
+pappso::QualifiedMassSpectrum
+MsRun::getQualifiedMassSpectrumBySpectrumIndex(std::size_t spectrum_index,
+                                               bool data)
+{
+
+  pappso::MsRunReaderSPtr msrun_reader_sp = getMsRunReaderSPtr();
+
+  if(msrun_reader_sp == nullptr)
+    {
+      msrun_reader_sp = findMsRunFile();
+      if(msrun_reader_sp == nullptr)
+        {
+          throw pappso::ExceptionNotFound(
+            QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+        }
+    }
+  qDebug();
+  msrun_reader_sp = getMsRunReaderSPtr();
+  if(msrun_reader_sp == nullptr)
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+    }
+
+  qDebug() << " spectrum file="
+           << msrun_reader_sp.get()->getMsRunId().get()->getFileName()
+           << " index=" << spectrum_index;
+  return msrun_reader_sp.get()->qualifiedMassSpectrum(spectrum_index, data);
+}
+
+
+std::size_t
+MsRun::scanNumber2SpectrumIndex(std::size_t scan_number)
+{
+
+  qDebug() << "scan=" << scan_number;
+  if(getMzFormat() == pappso::MzFormat::MGF)
+    {
+      scan_number = scan_number - 1;
+      qDebug() << "MGF format";
+    }
+  pappso::MsRunReaderSPtr msrun_reader_sp = getMsRunReaderSPtr();
+
+  if(msrun_reader_sp == nullptr)
+    {
+      msrun_reader_sp = findMsRunFile();
+      if(msrun_reader_sp == nullptr)
+        {
+          throw pappso::ExceptionNotFound(
+            QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+        }
+    }
+  qDebug();
+  msrun_reader_sp = getMsRunReaderSPtr();
+  if(msrun_reader_sp == nullptr)
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file not found").arg(getFileName()));
+    }
+
+
+  if(msrun_reader_sp.get()->hasScanNumbers())
+    {
+      qDebug() << "HAS SCAN NUMBERS";
+      return msrun_reader_sp.get()->scanNumber2SpectrumIndex(scan_number);
+    }
+  else
+    {
+      throw pappso::ExceptionNotFound(
+        QObject::tr("mz data \"%1\" file does not contain scan numbers")
+          .arg(getFileName()));
+    }
+}
