@@ -32,6 +32,7 @@
 
 #include "peptideevidence.h"
 #include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/exception/exceptionnotfound.h>
 
 std::hash<std::string> PeptideEvidence::_hash_fn;
 
@@ -39,6 +40,24 @@ PeptideEvidence::PeptideEvidence(MsRun *msrunid_sp, std::size_t scan_index)
 {
   _msrunid_sp   = msrunid_sp;
   m_scan_number = scan_index;
+  m_isSpectrumIndex =
+    false; // we are not sure as it were not defined. By default, consider it is
+           // a scan number to ensure compatibility
+
+  _hash_sample_scan      = PeptideEvidence::_hash_fn(QString("%1 %2")
+                                                  .arg(msrunid_sp->getXmlId())
+                                                  .arg(m_scan_number)
+                                                  .toStdString());
+  _identification_engine = IdentificationEngine::unknown;
+}
+
+PeptideEvidence::PeptideEvidence(MsRun *msrunid_sp,
+                                 std::size_t scan_index,
+                                 bool isSpectrumIndex)
+{
+  _msrunid_sp       = msrunid_sp;
+  m_scan_number     = scan_index;
+  m_isSpectrumIndex = isSpectrumIndex;
 
   _hash_sample_scan      = PeptideEvidence::_hash_fn(QString("%1 %2")
                                                   .arg(msrunid_sp->getXmlId())
@@ -48,7 +67,8 @@ PeptideEvidence::PeptideEvidence(MsRun *msrunid_sp, std::size_t scan_index)
 }
 
 PeptideEvidence::PeptideEvidence(const PeptideEvidence &other)
-  : PeptideEvidence(other._msrunid_sp, other.m_scan_number)
+  : PeptideEvidence(
+      other._msrunid_sp, other.m_scan_number, other.m_isSpectrumIndex)
 {
   _hash_sample_scan        = other._hash_sample_scan;
   _sp_grp_peptide          = other._sp_grp_peptide;
@@ -63,6 +83,7 @@ PeptideEvidence::PeptideEvidence(const PeptideEvidence &other)
   _proxy_valid             = other._proxy_valid;
   _identification_engine   = other._identification_engine;
   m_scan_number            = other.m_scan_number;
+  m_isSpectrumIndex        = other.m_isSpectrumIndex;
 }
 
 PeptideEvidence::~PeptideEvidence()
@@ -85,13 +106,15 @@ void
 PeptideEvidence::updateAutomaticFilters(
   const AutomaticFilterParameters &automatic_filter_parameters)
 {
+  // qDebug() << this->_p_identification_source;
   _proxy_valid =
     this->_p_identification_source->isValid(this, automatic_filter_parameters);
-
+  // qDebug();
   if(_proxy_valid)
     {
       unsigned int peprepro =
         automatic_filter_parameters.getFilterPeptideObservedInLessSamplesThan();
+      // qDebug();
       if(peprepro > 1)
         {
           if(this->getPeptideXtpSp().get()->getObservedMsrunList().size() <
@@ -102,6 +125,7 @@ PeptideEvidence::updateAutomaticFilters(
             }
         }
     }
+  // qDebug();
 }
 void
 PeptideEvidence::setRetentionTime(pappso::pappso_double rt)
@@ -383,3 +407,102 @@ PeptideEvidence::getGrpPeptideSp() const
 {
   return _sp_grp_peptide;
 }
+
+pappso::MassSpectrumCstSPtr
+PeptideEvidence::getMassSpectrumCstSPtr() const
+{
+  if(m_isSpectrumIndex)
+    {
+      return _msrunid_sp->getMassSpectrumCstSPtrBySpectrumIndex(m_scan_number);
+    }
+  else
+    {
+      return _msrunid_sp->getMassSpectrumCstSPtrByScanNumber(m_scan_number);
+    }
+}
+
+pappso::QualifiedMassSpectrum
+PeptideEvidence::getQualifiedMassSpectrum(bool data) const
+{
+
+  if(m_isSpectrumIndex)
+    {
+      return _msrunid_sp->getQualifiedMassSpectrumBySpectrumIndex(m_scan_number,
+                                                                  data);
+    }
+  else
+    {
+      return _msrunid_sp->getQualifiedMassSpectrumByScanNumber(m_scan_number,
+                                                               data);
+    }
+}
+
+
+std::size_t
+PeptideEvidence::getSpectrumIndex() const
+{
+  if(m_isSpectrumIndex)
+    {
+      return m_scan_number;
+    }
+  throw pappso::ExceptionNotFound(
+    QObject::tr(
+      "this peptide evidence has no spectrum index, only a scan number : %1")
+      .arg(m_scan_number));
+}
+
+
+std::size_t
+PeptideEvidence::getSpectrumIndexByScanNumber() const
+{
+  if(m_isSpectrumIndex)
+    {
+      return m_scan_number;
+    }
+  else
+    {
+      if(_msrunid_sp != nullptr)
+        {
+          return _msrunid_sp->scanNumber2SpectrumIndex(m_scan_number);
+        }
+      else
+        {
+          throw pappso::PappsoException(QObject::tr("_msrunid_sp == nullptr"));
+        }
+    }
+}
+
+
+QString
+PeptideEvidence::getHtmlSequence() const
+{
+  QString html = getPeptideXtpSp().get()->getSequence();
+
+  std::vector<std::size_t> position_list;
+  QVariant param = getParam(PeptideEvidenceParam::deepprot_delta_positions);
+  if(!param.isNull())
+    {
+      for(auto pos_str : param.toString().split(" ", QString::SkipEmptyParts))
+        {
+          position_list.push_back(pos_str.toUInt());
+        }
+    }
+
+  std::sort(position_list.begin(),
+            position_list.end(),
+            [](std::size_t a, std::size_t b) { return a > b; });
+
+  for(std::size_t pos : position_list)
+    {
+      html.insert(pos + 1, "</font>");
+      html.insert(pos, "<font color=\"red\">");
+    }
+
+  return html;
+}
+
+void
+PeptideEvidence::setIsSpectrumIndex(bool is_a_spectrum_index)
+{
+  m_isSpectrumIndex = is_a_spectrum_index;
+}
