@@ -493,6 +493,10 @@ MsIdentificationTableModel::data(const QModelIndex &index, int role) const
           {
             return showMsRunStatisticsStatus(row);
           }
+        if(col == (std::int8_t)msIdentificationListColumn::engine_name)
+          {
+            return QIcon(":/icons/resources/icons/open_new");
+          }
         return QVariant();
 
       case Qt::FontRole:
@@ -660,13 +664,7 @@ QVariant
 MsIdentificationTableModel::getMsRunStatisticsFollowingFormat(
   MsRunSp msrun_sp, MsRunStatistics column) const
 {
-  QString raw_format = QFileInfo(msrun_sp->getFileName()).completeSuffix();
-
-  if(raw_format != "tdf")
-    {
-      return msrun_sp->getMsRunStatistics(column);
-    }
-  else
+  if(msrun_sp->getMzFormat() == pappso::MzFormat::brukerTims)
     {
       if(column == MsRunStatistics::tic_spectra_ms1 ||
          column == MsRunStatistics::tic_spectra_ms2 ||
@@ -679,4 +677,8 @@ MsIdentificationTableModel::getMsRunStatisticsFollowingFormat(
           return msrun_sp->getMsRunStatistics(column);
         }
     }
+  else
+    {
+      return msrun_sp->getMsRunStatistics(column);
+    }
 }
