@@ -45,6 +45,12 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   setWindowTitle(QString("%1 %2").arg(SOFTWARE_NAME).arg(XTPCPP_VERSION));
   setWindowIcon(QIcon(":/xtpcpp_icon/resources/xtandempipeline_icon.svg"));
 
+
+  _p_app->setOrganizationName("PAPPSO");
+  _p_app->setOrganizationDomain("pappso.inra.fr");
+  _p_app->setApplicationName("xtpcpp");
+  _p_app->setApplicationVersion(XTPCPP_VERSION);
+
   mp_worker = new WorkerThread(this);
   mp_worker->moveToThread(&_worker_thread);
   _worker_thread.start();
@@ -58,6 +64,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
 
   ui->menu_export_files->setDisabled(true);
   ui->actionMassChroQ->setDisabled(true);
+  ui->menuMCQR->setDisabled(true);
   ui->centralwidget->layout()->addWidget(_project_window);
   _project_window->hide();
   ui->action_save_project->setDisabled(true);
@@ -89,14 +96,13 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
           &MainWindow::operateFreeAllMsRunReaders,
           _project_window,
           &ProjectWindow::doCleanMsRunReaders);
-
 #else
 #endif
 }
 
 MainWindow::~MainWindow()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   _worker_thread.quit();
   _worker_thread.wait();
   // if (_p_ms_data_file != nullptr) delete _p_ms_data_file;
@@ -105,17 +111,28 @@ MainWindow::~MainWindow()
   delete _p_load_results_dialog;
   delete _p_export_spreadsheet_dialog;
   delete _p_waiting_message_dialog;
+  delete mp_mcqrParamAllQuantiDialog;
+  delete mp_mcqrRunView;
   if(_p_export_masschroq_dialog != nullptr)
     {
       delete _p_export_masschroq_dialog;
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 bool
 MainWindow::stopWorkerThread()
 {
-  return _p_waiting_message_dialog->stopWorkerThread();
+  qDebug();
+  QMutexLocker mutex_locker(&m_mutex);
+  if(_p_waiting_message_dialog != nullptr)
+    {
+      return _p_waiting_message_dialog->stopWorkerThread();
+    }
+  else
+    {
+      return false;
+    }
 }
 
 void
@@ -130,16 +147,16 @@ MainWindow::closeEvent(QCloseEvent *event)
 
           switch(ret)
             {
-              case QMessageBox::Save:
+              case 0: // == DestructiveRole
+                event->accept();
+                break;
+              case 1: // == RejectRole
+                event->ignore();
+                break;
+              case 2: // == AcceptRole
                 doActionSaveProject();
                 event->accept();
                 break;
-              case QMessageBox::Discard:
-                event->accept();
-                break;
-              case QMessageBox::Cancel:
-                event->ignore();
-                break;
               default:
                 break;
             }
@@ -182,6 +199,7 @@ void
 MainWindow::doDisplayLoadingMessage(QString message)
 {
   qDebug() << message;
+  QMutexLocker mutex_locker(&m_mutex);
   _p_waiting_message_dialog->message(message);
   ui->statusbar->showMessage(message);
 }
@@ -190,31 +208,50 @@ void
 MainWindow::doDisplayLoadingMessagePercent(QString message, int value)
 {
   qDebug() << message << " " << value;
+  QMutexLocker mutex_locker(&m_mutex);
   _p_waiting_message_dialog->message(message, value);
   ui->statusbar->showMessage(message);
 }
 
+void
+MainWindow::doDisplayLoadingPercent(int value)
+{
+  qDebug() << value;
+  QMutexLocker mutex_locker(&m_mutex);
+  _p_waiting_message_dialog->percent(value);
+}
+
 void
 MainWindow::doWorkerSetText(QString text)
 {
+  QMutexLocker mutex_locker(&m_mutex);
   _p_waiting_message_dialog->setText(text);
 }
 void
 MainWindow::doWorkerAppendText(const char *text)
 {
+  QMutexLocker mutex_locker(&m_mutex);
   _p_waiting_message_dialog->appendText(text);
 }
+
+void
+MainWindow::doWorkerAppendQString(QString message)
+{
+  QMutexLocker mutex_locker(&m_mutex);
+  _p_waiting_message_dialog->appendText(message);
+}
+
 void
 MainWindow::doActionQuit()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   this->close();
 }
 
 void
 MainWindow::doAcceptedExportSpreadsheetDialog()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   try
     {
       QString format = this->_p_export_spreadsheet_dialog->getExportFormat();
@@ -242,8 +279,7 @@ MainWindow::doAcceptedExportSpreadsheetDialog()
           QDir parent(filename);
           parent.cdUp();
           settings.setValue("path/export_ods", parent.canonicalPath());
-          qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-                   << parent.absolutePath();
+          qDebug() << parent.absolutePath();
         }
       if(filename.isEmpty())
         {
@@ -261,23 +297,23 @@ MainWindow::doAcceptedExportSpreadsheetDialog()
       viewError(tr("Error while writing ODS file :\n%1").arg(error.qwhat()));
     }
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doAcceptedTandemRunDialog()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   showWaitingMessage(tr("Running X!Tandem"));
-
+  qDebug();
   emit operateRunningXtandem(_p_tandem_run_dialog->getTandemRunBatch());
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doAcceptedLoadResultDialog()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   AutomaticFilterParameters param =
     _p_load_results_dialog->getAutomaticFilterParameters();
   QSettings settings;
@@ -296,7 +332,7 @@ MainWindow::doAcceptedLoadResultDialog()
 
   showWaitingMessage(tr("Loading files"));
   emit operateLoadingResults(is_individual, param, file_list);
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
@@ -339,20 +375,52 @@ MainWindow::doProjectReady(ProjectSp project_sp)
 
   ui->menu_export_files->setDisabled(false);
   ui->actionMassChroQ->setDisabled(false);
+  ui->menuMCQR->setDisabled(false);
   ui->actionModifications->setDisabled(false);
   ui->actionLabeling_methods->setDisabled(false);
 
-  std::vector<MsRunAlignmentGroupSp> group_list =
-    _project_sp->getMsRunAlignmentGroupList();
-  if(_project_sp->getMsRunAlignmentGroupList().size() == 0)
+  // Create the alignment group with all the msrun within
+  if(_project_sp->getAllMsRunAlignmentGroup() == nullptr)
     {
-      std::shared_ptr<MsRunAlignmentGroup> name =
-        std::make_shared<MsRunAlignmentGroup>(_project_sp.get(), "All");
+      std::shared_ptr<MsRunAlignmentGroup> all_msrun_group =
+        std::make_shared<MsRunAlignmentGroup>(_project_sp.get(), "all_msrun");
       for(MsRunSp ms_run_sp : _project_sp->getMsRunStore().getMsRunList())
         {
-          name->addMsRunToMsRunAlignmentGroupList(ms_run_sp);
+          all_msrun_group->addMsRunToMsRunAlignmentGroupList(ms_run_sp);
         }
-      _project_sp->addMsRunAlignmentGroupToList(name);
+      _project_sp->setAllMsRunAlignmentGroup(all_msrun_group);
+    }
+
+  // Check if the MCQR action can be enabled and add the corresponding actions
+  ui->menuAnalyze_one_group->clear();
+  ui->menu_SDS_analysis->clear();
+  for(MsRunAlignmentGroupSp align_group :
+      _project_sp->getMsRunAlignmentGroupList())
+    {
+      if(align_group->getGroupStatus() == AlignmentGroupStatus::masschroq_run)
+        {
+          ui->menuAnalyze_one_group->addAction(
+            align_group->getMsRunAlignmentGroupName());
+          bool already_exist = false;
+          for(QAction *action : ui->menu_SDS_analysis->actions())
+            {
+              if(action->text() ==
+                 QFileInfo(align_group->getMassChroqmlPath()).baseName())
+                {
+                  already_exist = true;
+                }
+            }
+          if(!already_exist)
+            {
+              qDebug() << align_group->getMassChroqmlPath();
+              ui->menu_SDS_analysis->addAction(
+                QFileInfo(align_group->getMassChroqmlPath()).baseName());
+            }
+        }
+    }
+  if(ui->menu_SDS_analysis->actions().size() > 0)
+    {
+      ui->menu_SDS_analysis->setEnabled(true);
     }
 
   // Reset masschroq_run_dialog with new project
@@ -375,6 +443,13 @@ MainWindow::doActionLabelingMethods()
 {
   _project_window->editLabelingMethods();
 }
+
+void
+MainWindow::doActionDeepProtStudio()
+{
+  _project_window->deepProtPostProcessInterface();
+}
+
 void
 MainWindow::doActionModifications()
 {
@@ -424,6 +499,7 @@ void
 MainWindow::hideWaitingMessage()
 {
 
+  QMutexLocker mutex_locker(&m_mutex);
   _p_waiting_message_dialog->hide();
   ui->statusbar->showMessage("");
 }
@@ -431,10 +507,15 @@ MainWindow::hideWaitingMessage()
 void
 MainWindow::showWaitingMessage(const QString title)
 {
+  QMutexLocker mutex_locker(&m_mutex);
+  qDebug();
   _p_waiting_message_dialog->setWindowTitle(title);
+  qDebug();
   _p_waiting_message_dialog->show();
+  qDebug();
   _p_waiting_message_dialog->raise();
   _p_waiting_message_dialog->activateWindow();
+  qDebug();
 }
 
 void
@@ -499,6 +580,7 @@ MainWindow::doActionSaveProject()
       emit operateWritingXpipFile(filename, _project_sp);
       _project_sp.get()->setProjectName(filename);
       showProjectName();
+      _project_sp->setProjectChangedStatus(false);
     }
   catch(pappso::PappsoException &error)
     {
@@ -509,7 +591,7 @@ MainWindow::doActionSaveProject()
 void
 MainWindow::doActionSpreadsheet()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   try
     {
       if(_project_sp.get() != nullptr)
@@ -524,13 +606,13 @@ MainWindow::doActionSpreadsheet()
     {
       viewError(tr("Error doActionSpreadsheet :\n%1").arg(error.qwhat()));
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doActionSpectralCountingMcq()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 
   QSettings settings;
   QString default_location = settings.value("path/scmcqfile", "").toString();
@@ -551,7 +633,7 @@ MainWindow::doActionSpectralCountingMcq()
   showWaitingMessage(tr("Writing %1 spectral count file for MassChroqR")
                        .arg(QFileInfo(filename).fileName()));
   emit operateWritingMcqrSpectralCountFile(filename, _project_sp);
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
@@ -632,7 +714,7 @@ MainWindow::doActionFastaOneByGroup()
 void
 MainWindow::doActionMassChroQ()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 
   try
     {
@@ -658,14 +740,87 @@ MainWindow::doActionMassChroQ()
     {
       viewError(tr("Error doActionMassChroQ :\n%1").arg(error.qwhat()));
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
+void
+MainWindow::doActionScMcqr()
+{
+  qDebug() << "Run SC analysis";
+  try
+    {
+      if(mp_mcqrParamAllQuantiDialog != nullptr)
+        {
+          delete mp_mcqrParamAllQuantiDialog;
+          mp_mcqrParamAllQuantiDialog = nullptr;
+        }
+      mp_mcqrParamAllQuantiDialog =
+        new McqrParamAllQuantiDialog(this, _project_sp);
+      mp_mcqrParamAllQuantiDialog->show();
+      mp_mcqrParamAllQuantiDialog->raise();
+      mp_mcqrParamAllQuantiDialog->activateWindow();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(tr("Error while running MCQR parameter window :\n%1")
+                  .arg(error.qwhat()));
+    }
+}
+
+void
+MainWindow::doActionXicMcqr(QAction *action)
+{
+  qDebug() << "begin";
+  if(action != nullptr)
+    {
+      try
+        {
+          if(mp_mcqrParamAllQuantiDialog != nullptr)
+            {
+              delete mp_mcqrParamAllQuantiDialog;
+              mp_mcqrParamAllQuantiDialog = nullptr;
+            }
+          mp_mcqrParamAllQuantiDialog =
+            new McqrParamAllQuantiDialog(this, _project_sp, action->text());
+          mp_mcqrParamAllQuantiDialog->show();
+          mp_mcqrParamAllQuantiDialog->raise();
+          mp_mcqrParamAllQuantiDialog->activateWindow();
+        }
+      catch(pappso::PappsoException &error)
+        {
+          viewError(tr("Error while running MCQR parameter window :\n%1")
+                      .arg(error.qwhat()));
+        }
+    }
+  qDebug() << "end";
+}
+
+void
+MainWindow::doActionOneGroupMcqr(QAction *action_group)
+{
+  if(action_group != nullptr)
+    {
+      QMessageBox message_box;
+      message_box.setWindowTitle(tr("Work in progress"));
+      message_box.setIcon(QMessageBox::Information);
+      message_box.setText(tr("The MCQR analysis of one group only such as %1 "
+                             "is not implemented yet!")
+                            .arg(action_group->text()));
+      message_box.exec();
+    }
+}
+
+void
+MainWindow::doCloseMcqrRunView()
+{
+  qDebug() << "ask to close McqrRunView";
+  delete mp_mcqrRunView;
+}
 
 void
 MainWindow::doAcceptedMassChroqRunDialog()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   try
     {
 
@@ -676,11 +831,13 @@ MainWindow::doAcceptedMassChroqRunDialog()
       QSettings settings;
       QString default_location = settings.value("path/mcqfile", "").toString();
 
-      QString filename = QFileDialog::getSaveFileName(
-        this,
-        tr("Save MassChroqML file"),
-        QString("%1/untitled.masschroqml").arg(default_location),
-        tr("MassChroqML (*.masschroqml)"));
+      QString filename =
+        QFileDialog::getSaveFileName(this,
+                                     tr("Save MassChroqML file"),
+                                     tr("%1/%2.masschroqml")
+                                       .arg(default_location)
+                                       .arg(_project_sp->getProjectName()),
+                                     tr("MassChroqML (*.masschroqml)"));
 
       if(filename.isEmpty())
         {
@@ -699,25 +856,97 @@ MainWindow::doAcceptedMassChroqRunDialog()
         tr("Error while writing MassChroqML file :\n%1").arg(error.qwhat()));
     }
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
-MainWindow::doWritingMassChroQmlFileFinished(QString masschroqml_file)
+MainWindow::doAcceptedMcqrParamAllQuantiDialog()
 {
+  qDebug();
+
+  qDebug() << "begin";
+  try
+    {
+      McqrExperimentSp mcqr_experiment =
+        _project_sp.get()->getMcqrExperimentSp();
+      QSettings settings;
+      QString default_location = settings.value("mcqr/rdata_path").toString();
+      QString rdata_path =
+        QFileDialog::getSaveFileName(this,
+                                     tr("save RData file"),
+                                     tr("%1/%2.RData")
+                                       .arg(default_location)
+                                       .arg(_project_sp->getProjectName()),
+                                     tr("RData files ( *.RData)"));
+
+
+      if(!rdata_path.isEmpty())
+        {
+
+          mcqr_experiment.get()->setRdataFilePath(
+            QFileInfo(rdata_path).absoluteFilePath());
+          showWaitingMessage(tr("Writing %1 RData file").arg(rdata_path));
+          settings.setValue("mcqr/rdata_path",
+                            mcqr_experiment.get()->getRdataFilePath());
+
+          emit operateWritingMcqrRData(mcqr_experiment, _project_sp);
+        }
+    }
+  catch(pappso::PappsoException &error)
+    {
+      viewError(
+        tr("Error while writing Mcqr RData file:\n%1").arg(error.qwhat()));
+    }
+}
+
+void
+MainWindow::doWritingRdataFileFinished(McqrExperimentSp p_mcqr_experiment)
+{
+  qDebug() << "RData file created";
+  hideWaitingMessage();
+  if(mp_mcqrParamAllQuantiDialog->getMcqrRunStatus())
+    {
+      mp_mcqrRunView =
+        new McqrRunView(this,
+                        p_mcqr_experiment,
+                        mp_mcqrParamAllQuantiDialog->getMassChroqResultsUsed());
+      mp_mcqrRunView->show();
+      mp_mcqrRunView->raise();
+      mp_mcqrRunView->activateWindow();
+      qDebug() << "Run Mcqr!!";
+    }
+}
+
+
+void
+MainWindow::doWritingMassChroQmlFileFinished(
+  QString masschroqml_file,
+  std::vector<MsRunAlignmentGroupSp> quantified_groups)
+{
+  qDebug() << "MassChroQml created";
   if(_p_export_masschroq_dialog->getMassChroqRunStatus())
     {
       _p_export_masschroq_dialog->setMassChroqRunBatchParam(masschroqml_file);
       showWaitingMessage(tr("Running MassChroQ"));
       emit operateRunningMassChroq(
         _p_export_masschroq_dialog->getMassChroqRunBatchParam());
+      ui->menu_SDS_analysis->addAction(QFileInfo(masschroqml_file).baseName());
+      ui->menu_SDS_analysis->setEnabled(true);
+      for(MsRunAlignmentGroupSp group : quantified_groups)
+        {
+          ui->menuAnalyze_one_group->addAction(
+            group->getMsRunAlignmentGroupName());
+        }
+      ui->menuMCQR->setDisabled(false);
     }
+  _p_export_masschroq_dialog->updateAlignmentGroupsStatus(masschroqml_file);
+  _project_window->projectStatusChanged();
 }
 
 void
 MainWindow::doActionMassChroqPRM()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   try
     {
       _project_sp.get()->checkPsimodCompliance();
@@ -749,13 +978,13 @@ MainWindow::doActionMassChroqPRM()
       viewError(
         tr("Error while writing MassChroqML file :\n%1").arg(error.qwhat()));
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doActionProticDb()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   try
     {
       _project_sp.get()->checkPsimodCompliance();
@@ -787,13 +1016,13 @@ MainWindow::doActionProticDb()
       viewError(
         tr("Error while writing PROTICdbML file :\n%1").arg(error.qwhat()));
     }
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doActionAbout()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   if(_p_about_dialog == nullptr)
     {
       _p_about_dialog = new AboutDialog(this);
@@ -802,13 +1031,13 @@ MainWindow::doActionAbout()
   _p_about_dialog->raise();
   _p_about_dialog->activateWindow();
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 MainWindow::doActionSettings()
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   if(_p_edit_settings == nullptr)
     {
       _p_edit_settings = new EditSettings(this);
@@ -817,7 +1046,7 @@ MainWindow::doActionSettings()
   _p_edit_settings->raise();
   _p_edit_settings->activateWindow();
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
@@ -826,17 +1055,24 @@ MainWindow::doCheckNewVersion()
   qDebug();
   if(m_onlineVersion.isNewVersion())
     {
-
       hideWaitingMessage();
-      int ret = QMessageBox::warning(
-        this,
-        tr("new version available"),
+      QMessageBox *version_message_box = new QMessageBox(this);
+      version_message_box->setWindowTitle(tr("new version available"));
+      version_message_box->setText(
         tr("A new %1 version is available %2\nCheck our web site \n"
            "%3\n to download it")
           .arg(SOFTWARE_NAME)
           .arg(m_onlineVersion.getVersion())
           .arg(m_onlineVersion.getPermalink()));
-      if(ret == QMessageBox::Ok)
+      QPushButton *download_button = version_message_box->addButton(
+        tr("Download version %1").arg(m_onlineVersion.getVersion()),
+        QMessageBox::AcceptRole);
+      version_message_box->addButton(
+        tr("Keep version %1").arg(m_onlineVersion.getVersion()),
+        QMessageBox::RejectRole);
+
+      version_message_box->exec();
+      if(version_message_box->clickedButton() == download_button)
         {
           QDesktopServices::openUrl(QUrl(m_onlineVersion.getPermalink()));
         }
@@ -857,7 +1093,7 @@ MainWindow::run()
 
   try
     {
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      qDebug();
       QCommandLineParser parser;
 
       // throw pappso::PappsoException("test");
@@ -869,7 +1105,7 @@ MainWindow::run()
         "XPIP project file",
         QCoreApplication::translate("main", "Project file to open."));
 
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      qDebug();
 
       // Process the actual command line arguments given by the user
       parser.process(*_p_app);
@@ -920,10 +1156,23 @@ MainWindow::chooseSaveMssgBox()
     QString("Save %1 Project?").arg(_project_sp.get()->getProjectName()));
   save_box.setText("The project has been modified.");
   save_box.setInformativeText("Do you want to save your changes?");
-  save_box.setStandardButtons(QMessageBox::Save | QMessageBox::Discard |
-                              QMessageBox::Cancel);
-  save_box.setDefaultButton(QMessageBox::Save);
+  save_box.addButton(
+    new QPushButton(QIcon(":/icons/resources/icons/mit/ionicons/trash-bin"),
+                    tr("Close without saving")),
+    QMessageBox::DestructiveRole);
+  save_box.addButton(
+    new QPushButton(QIcon(":/icons/resources/icons/apache/unicons/cancel"),
+                    tr("&Cancel")),
+    QMessageBox::RejectRole);
+  save_box.addButton(
+    new QPushButton(QIcon(":/icons/resources/icons/apache/firefox/floppydisk2"),
+                    tr("&Save")),
+    QMessageBox::AcceptRole);
+  //   save_box.setStandardButtons(QMessageBox::Save | QMessageBox::Discard |
+  //                               QMessageBox::Cancel);
+  //   save_box.setDefaultButton(QMessageBox::Save);
   int ret = save_box.exec();
+  qDebug() << ret;
   return ret;
 }
 
@@ -938,3 +1187,15 @@ MainWindow::doFreeAllMsRunReaders()
 {
   emit operateFreeAllMsRunReaders();
 }
+
+void
+MainWindow::enableDeepProtStudio(bool enabled)
+{
+  ui->actionDeepProt_studio->setEnabled(enabled);
+}
+
+void
+MainWindow::doShowStopButton()
+{
+  _p_waiting_message_dialog->showStopButton();
+}
