@@ -1,3 +1,6 @@
+/** @file src/gui/mainwindow.h
+ * Main window and central widget of X!TandemPipeline
+ */
 
 /*******************************************************************************
  * Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
@@ -17,9 +20,6 @@
  *     You should have received a copy of the GNU General Public License
  *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contributors:
- *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
- *implementation
  ******************************************************************************/
 
 
@@ -43,6 +43,8 @@
 #include "gui/edit/edit_settings/editsettings.h"
 #include "gui/masschroq_run_dialog/masschroqrundialog.h"
 #include "workerthread.h"
+#include "gui/mcqr_param_dialog/mcqrparamallquantidialog.h"
+#include "gui/mcqr_run_view/mcqrrunview.h"
 
 
 namespace Ui
@@ -65,6 +67,11 @@ class MainWindow : public QMainWindow
   bool stopWorkerThread();
   WorkerThread *getWorkerThread();
 
+
+  /** @brief enable or disable DeepProt studio feature
+   */
+  void enableDeepProtStudio(bool enabled);
+
   public slots:
   void run();
   void loadResults();
@@ -75,9 +82,14 @@ class MainWindow : public QMainWindow
   void doActionFastaOneBySubgroup();
   void doActionFastaOneByGroup();
   void doActionMassChroQ();
+  void doActionXicMcqr(QAction *action);
+  void doActionScMcqr();
+  void doActionOneGroupMcqr(QAction *action_group);
+  void doCloseMcqrRunView();
   void doActionMassChroqPRM();
   void doActionProticDb();
   void doActionLabelingMethods();
+  void doActionDeepProtStudio();
   void doActionTandemRun();
   void doActionSettings();
   void doActionSpreadsheet();
@@ -85,9 +97,11 @@ class MainWindow : public QMainWindow
   void doActionSaveProject();
   void doDisplayLoadingMessage(QString message);
   void doDisplayLoadingMessagePercent(QString message, int value);
+  void doDisplayLoadingPercent(int value);
   void doDisplayJobFinished(QString message);
   void doDisplayJobCanceled(QString message);
   void doWorkerAppendText(const char *);
+  void doWorkerAppendQString(QString message);
   void doWorkerSetText(QString);
   void doProjectReady(ProjectSp project_sp);
   void doLoadingResultsReady(ProjectSp project_sp);
@@ -96,13 +110,18 @@ class MainWindow : public QMainWindow
   void doAcceptedTandemRunDialog();
   void doAcceptedExportSpreadsheetDialog();
   void doAcceptedMassChroqRunDialog();
-  void doWritingMassChroQmlFileFinished(QString masschroqml_file);
+  void doAcceptedMcqrParamAllQuantiDialog();
+  void doWritingMassChroQmlFileFinished(
+    QString masschroqml_file,
+    std::vector<MsRunAlignmentGroupSp> quantified_groups);
+  void doWritingRdataFileFinished(McqrExperimentSp p_mcqr_experiment);
   void doOperationFailed(QString);
   void doOperationFinished();
   void doGroupingFinished();
   void doActionSpectralCountingMcq();
   void doCheckNewVersion();
   void doFreeAllMsRunReaders();
+  void doShowStopButton();
   // void peptideEdited(QString peptideStr);
   // void setColor(const QColor &color);
   // void setShape(Shape shape);
@@ -118,6 +137,8 @@ class MainWindow : public QMainWindow
   void operateWritingMassChroqFile(QString filename,
                                    ProjectSp project_sp,
                                    MasschroqFileParameters params);
+  void operateWritingMcqrRData(McqrExperimentSp mcqr_experiment_sp,
+                               ProjectSp project);
   void operateWritingMassChroqPrmFile(QString filename, ProjectSp project_sp);
   void operateWritingProticFile(QString filename, ProjectSp project_sp);
   void operateWritingMcqrSpectralCountFile(QString filename,
@@ -161,10 +182,13 @@ class MainWindow : public QMainWindow
   LoadResultsDialog *_p_load_results_dialog             = nullptr;
   ExportSpreadsheetDialog *_p_export_spreadsheet_dialog = nullptr;
   MassChroqRunDialog *_p_export_masschroq_dialog        = nullptr;
-  WaitingMessageDialog *_p_waiting_message_dialog;
-  AboutDialog *_p_about_dialog          = nullptr;
-  TandemRunDialog *_p_tandem_run_dialog = nullptr;
-  EditSettings *_p_edit_settings        = nullptr;
+  McqrParamAllQuantiDialog *mp_mcqrParamAllQuantiDialog = nullptr;
+  McqrRunView *mp_mcqrRunView                           = nullptr;
+  WaitingMessageDialog *_p_waiting_message_dialog       = nullptr;
+  AboutDialog *_p_about_dialog                          = nullptr;
+  TandemRunDialog *_p_tandem_run_dialog                 = nullptr;
+  EditSettings *_p_edit_settings                        = nullptr;
 
   HttpVersion m_onlineVersion;
+  QMutex m_mutex;
 };
