@@ -36,6 +36,7 @@
 #include <pappsomspp/pappsoexception.h>
 #include "../mainwindow.h"
 #include "../../utils/utils.h"
+#include "../../output/mcqr/mcqrdata.h"
 
 MassChroqRunDialog::MassChroqRunDialog(MainWindow *parent,
                                        WorkerThread *p_worker)
@@ -58,7 +59,7 @@ MassChroqRunDialog::MassChroqRunDialog(MainWindow *parent,
   ui->use_ht_condor_group->setChecked(
     settings.value("masschroq/use_htcondor", "false").toBool());
   ui->ht_condor_memory_spin->setValue(
-    settings.value("masschroq/htcondor_memory", "5000").toInt());
+    settings.value("masschroq/condor_request_memory", "5000").toInt());
 
   setMassChroQRunParamTab();
   mp_poModel = new QStandardItemModel(ui->group_listView);
@@ -92,7 +93,7 @@ MassChroqRunDialog::MassChroqRunDialog(MainWindow *parent,
           &MassChroqRunDialog::setCheckMsrunFilePathOk);
 
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 MassChroqRunDialog::~MassChroqRunDialog()
@@ -120,8 +121,7 @@ MassChroqRunDialog::setMasschroqFileParameters(
     {
       ui->outputFileFormatComboBox->setCurrentText("TSV");
     }
-
-  ui->compar_radioButton->setChecked(params.export_compar_file);
+  setComparFileValue(params.export_compar_file);
 
   ui->timeCorrectionGroupBox->setChecked(params.write_alignment_times);
   ui->timeCorrectionDirectoryEdit->setText(params.alignment_times_directory);
@@ -144,16 +144,22 @@ MassChroqRunDialog::getMasschroqFileParameters() const
     {
       params.result_file_format = TableFileFormat::tsv;
     }
-  for(int i = 0; i < mp_poModel->rowCount(); i++)
+
+  if(mp_poModel->item(0, 0)->checkState() == Qt::CheckState(Qt::Checked))
+    {
+      qDebug() << msp_allMsrunAlignmentGroup->getMsRunAlignmentGroupName();
+      params.alignment_groups.push_back(msp_allMsrunAlignmentGroup);
+    }
+  for(int i = 1; i < mp_poModel->rowCount(); i++)
     {
       qDebug() << mp_poModel->item(i, 0)->checkState();
       if(mp_poModel->item(i, 0)->checkState() == Qt::CheckState(Qt::Checked))
         {
-          params.alignment_groups.push_back(msp_alignmentGroups.at(i));
+          params.alignment_groups.push_back(msp_alignmentGroups.at(i - 1));
         }
     }
 
-  params.export_compar_file = ui->compar_radioButton->isChecked();
+  params.export_compar_file = m_writeComparFile;
 
   params.write_alignment_times     = ui->timeCorrectionGroupBox->isChecked();
   params.alignment_times_directory = ui->timeCorrectionDirectoryEdit->text();
@@ -183,6 +189,13 @@ MassChroqRunDialog::reject()
 void
 MassChroqRunDialog::accept()
 {
+  if(ui->use_ht_condor_group->isChecked())
+    {
+      QSettings settings;
+      settings.setValue("masschroq/condor_disk_usage",
+                        ui->ht_condor_memory_spin->value());
+    }
+
   QString error_message;
   if(ui->timeCorrectionGroupBox->isChecked())
     {
@@ -332,9 +345,17 @@ MassChroqRunDialog::setCheckMsrunFilePathOk(MsRunSp msrun_sp)
 void
 MassChroqRunDialog::setAlignmentGroups()
 {
-  // ui->listWidget_2->clear();
+  // Add all msrun stored group (automatic group)
+  msp_allMsrunAlignmentGroup = msp_project->getAllMsRunAlignmentGroup();
+  QStandardItem *all_msrun_item =
+    new QStandardItem(msp_allMsrunAlignmentGroup->getMsRunAlignmentGroupName());
+  all_msrun_item->setCheckable(true);
+  all_msrun_item->setData(Qt::Unchecked, Qt::CheckStateRole);
+  mp_poModel->setItem(0, all_msrun_item);
+
+  // Add classical groups
   msp_alignmentGroups = msp_project->getMsRunAlignmentGroupList();
-  int i               = 0;
+  int i               = 1;
   for(MsRunAlignmentGroupSp group : msp_alignmentGroups)
     {
       QStandardItem *new_item =
@@ -352,7 +373,14 @@ MassChroqRunDialog::doShowMsRunsInAlignmentGroup(QModelIndex index)
 {
   ui->listWidget->clear();
   ui->msrun_list_combo_box->clear();
-  msp_selected_group = msp_alignmentGroups.at(index.row());
+  if(index.row() == 0)
+    {
+      msp_selected_group = msp_allMsrunAlignmentGroup;
+    }
+  else
+    {
+      msp_selected_group = msp_alignmentGroups.at(index.row() - 1);
+    }
   ui->groupBox_5->setTitle("Ms runs in " +
                            msp_selected_group->getMsRunAlignmentGroupName());
   for(MsRunSp ms_run : msp_selected_group->getMsRunsInAlignmentGroup())
@@ -362,14 +390,14 @@ MassChroqRunDialog::doShowMsRunsInAlignmentGroup(QModelIndex index)
     }
   if(msp_selected_group->getMsRunReference() != nullptr)
     {
-      int index = 0;
+      int ref_index = 0;
       for(MsRunSp ms_run : msp_selected_group->getMsRunsInAlignmentGroup())
         {
           if(ms_run == msp_selected_group->getMsRunReference())
             {
-              ui->msrun_list_combo_box->setCurrentIndex(index);
+              ui->msrun_list_combo_box->setCurrentIndex(ref_index);
             }
-          index++;
+          ref_index++;
         }
     }
   else
@@ -501,3 +529,84 @@ MassChroqRunDialog::setMassChroQRunParamTab()
   ui->peptide_checkbox->setChecked(
     settings.value("masschroq/parse_peptide", "false").toBool());
 }
+
+void
+MassChroqRunDialog::updateAlignmentGroupsStatus(QString masschroqml_file)
+{
+  for(int i = 0; i < mp_poModel->rowCount(); i++)
+    {
+      if(mp_poModel->item(i, 0)->checkState() == Qt::CheckState(Qt::Checked))
+        {
+          MsRunAlignmentGroupSp group;
+          if(i == 0) // All msruns item
+            {
+              group = msp_allMsrunAlignmentGroup;
+            }
+          else
+            {
+              group = msp_alignmentGroups.at(i - 1);
+            }
+          ZivyParams zivy_params;
+          zivy_params.loadSettings();
+          group->savePostMassChroqmlParameters(
+            getMasschroqFileParameters(), zivy_params, masschroqml_file);
+          if(getMassChroqRunStatus() == true)
+            {
+              group->setMassChroQRunStatus(AlignmentGroupStatus::masschroq_run);
+            }
+          else
+            {
+              group->setMassChroQRunStatus(
+                AlignmentGroupStatus::masschroqml_written);
+            }
+        }
+    }
+}
+
+void
+MassChroqRunDialog::setComparFileValue(bool write_compar)
+{
+  if(write_compar)
+    {
+      m_writeComparFile = true;
+      ui->compar_button->setIcon(
+        QIcon(":/icons/resources/icons/switch_on.svg"));
+    }
+  else
+    {
+      m_writeComparFile = false;
+      ui->compar_button->setIcon(
+        QIcon(":/icons/resources/icons/switch_off.svg"));
+    }
+}
+
+void
+MassChroqRunDialog::doUpdateComparButton()
+{
+  if(m_writeComparFile)
+    {
+      m_writeComparFile = false;
+      ui->compar_button->setIcon(
+        QIcon(":/icons/resources/icons/switch_off.svg"));
+    }
+  else
+    {
+      m_writeComparFile = true;
+      ui->compar_button->setIcon(
+        QIcon(":/icons/resources/icons/switch_on.svg"));
+    }
+}
+
+void
+MassChroqRunDialog::checkTabToEnableMassChroQRun(int tab_position)
+{
+  qDebug() << tab_position;
+  if(tab_position == 3) // MassChroQ execution tab_position
+    {
+      ui->runMCQButton->setEnabled(true);
+    }
+  else
+    {
+      ui->runMCQButton->setEnabled(false);
+    }
+}
