@@ -28,6 +28,7 @@
 #include "ui_peptide_detail_view.h"
 #include <pappsomspp/exception/exceptionnotfound.h>
 #include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/msfile/mzformatenumstr.h>
 #include <QFileDialog>
 #include <QSettings>
 #include <QDebug>
@@ -44,9 +45,7 @@ SpectrumSpLoaderThread::doLoadSpectrumSp(PeptideEvidence *p_peptide_evidence)
   pappso::MassSpectrumCstSPtr spectrum;
   try
     {
-      spectrum =
-        p_peptide_evidence->getIdentificationDataSource()
-          ->getMassSpectrumCstSPtr(p_peptide_evidence->getScanNumber());
+      spectrum = p_peptide_evidence->getMassSpectrumCstSPtr();
 
 
       emit spectrumSpReady(spectrum, QString(""), QString(""));
@@ -54,31 +53,28 @@ SpectrumSpLoaderThread::doLoadSpectrumSp(PeptideEvidence *p_peptide_evidence)
 
   catch(pappso::ExceptionNotFound &error)
     {
-      qDebug() << "SpectrumSpLoaderThread::doLoadSpectrumSp error "
-               << error.qwhat();
+      qDebug() << error.qwhat();
       emit spectrumSpReady(spectrum, error.qwhat(), QString(""));
     }
 
   catch(pappso::PappsoException &error)
     {
-      qDebug() << "SpectrumSpLoaderThread::doLoadSpectrumSp error "
-               << error.qwhat();
+      qDebug() << error.qwhat();
       emit spectrumSpReady(spectrum, QString(""), error.qwhat());
     }
 
   catch(std::exception &error)
     {
-      qDebug() << "SpectrumSpLoaderThread::doLoadSpectrumSp error "
-               << error.what();
+      qDebug() << error.what();
       emit spectrumSpReady(spectrum, QString(""), QString(error.what()));
     }
-  qDebug() << "SpectrumSpLoaderThread::doLoadSpectrumSp end";
+  qDebug();
 }
 
 PeptideWindow::PeptideWindow(ProjectWindow *parent)
   : QMainWindow(parent), ui(new Ui::PeptideDetailView)
 {
-  qDebug() << "PeptideWindow::PeptideWindow begin";
+  qDebug() << "begin";
   _p_project_window = parent;
   ui->setupUi(this);
   /*
@@ -127,6 +123,9 @@ PeptideWindow::PeptideWindow(ProjectWindow *parent)
   ui->spectrum_widget->setMaximumIsotopeNumber(3);
   ui->spectrum_widget->setMaximumIsotopeRank(6);
 
+  ui->pushButton->setVisible(checkPeptideViewerWorking());
+
+
 #if QT_VERSION >= 0x050000
   // Qt5 code
   connect(_p_project_window,
@@ -184,7 +183,7 @@ PeptideWindow::PeptideWindow(ProjectWindow *parent)
   // SLOT(updateStatusBar()));
 #endif
 
-  qDebug() << "PeptideWindow::PeptideWindow end";
+  qDebug() << "end";
 }
 
 PeptideWindow::~PeptideWindow()
@@ -224,7 +223,7 @@ PeptideWindow::setIon(pappso::PeakIonIsotopeMatchCstSPtr ion)
 void
 PeptideWindow::setPeak(pappso::DataPointCstSPtr p_peak_match)
 {
-  qDebug() << "PeptideWindow::setPeak begin";
+  qDebug() << "begin";
   if(p_peak_match == nullptr)
     {
       _peak_label->setText(QString("no peak"));
@@ -263,16 +262,37 @@ PeptideWindow::updateDisplay()
 {
   try
     {
-      ui->sequence_label->setText(
-        _p_peptide_evidence->getPeptideXtpSp().get()->toString());
+      qDebug();
+      ui->sequence_label->setText(_p_peptide_evidence->getHtmlSequence());
       ui->mz_label->setText(
         QString("%1").arg(_p_peptide_evidence->getPeptideXtpSp().get()->getMz(
           _p_peptide_evidence->getCharge())));
       ui->z_label->setText(QString("%1").arg(_p_peptide_evidence->getCharge()));
-      ui->scan_label->setText(
-        QString("%1").arg(_p_peptide_evidence->getScanNumber()));
+
+      if(_p_peptide_evidence->getMsRunP()->getMzFormat() ==
+         pappso::MzFormat::unknown)
+        {
+
+          ui->scan_label->setText(
+            QString("%1").arg(_p_peptide_evidence->getScanNumber()));
+        }
+      else
+        {
+          ui->scan_label->setText(
+            QString("%1 : %2")
+              .arg(_p_peptide_evidence->getScanNumber())
+              .arg(pappso::MzFormatEnumStr::toString(
+                _p_peptide_evidence->getMsRunP()->getMzFormat())));
+          ui->scan_label->setToolTip(
+            QString("scan number %1 in %2 format")
+              .arg(_p_peptide_evidence->getScanNumber())
+              .arg(pappso::MzFormatEnumStr::toString(
+                _p_peptide_evidence->getMsRunP()->getMzFormat())));
+        }
       ui->sample_label->setText(
         _p_peptide_evidence->getMsRunP()->getSampleName());
+      ui->sample_label->setToolTip(
+        _p_peptide_evidence->getMsRunPtr()->getFileName());
       ui->modification_label->setText(
         _p_peptide_evidence->getPeptideXtpSp().get()->getModifString());
       ui->hyperscore_label->setText(
@@ -295,6 +315,9 @@ PeptideWindow::updateDisplay()
         QString::number(_p_peptide_evidence->getRetentionTime(), 'f', 2));
       ui->retention_time_min_label->setText(
         QString::number(_p_peptide_evidence->getRetentionTime() / 60, 'f', 2));
+
+      qDebug();
+      updateIonMobilityDisplay();
     }
   catch(pappso::PappsoException &exception_pappso)
     {
@@ -309,6 +332,55 @@ PeptideWindow::updateDisplay()
     }
 }
 
+void
+PeptideWindow::updateIonMobilityDisplay()
+{
+  qDebug();
+
+  ui->ion_mobility_form_widget->hide();
+  ui->ion_mobility_line->hide();
+  pappso::QualifiedMassSpectrum mass_spectrum;
+  try
+    {
+      mass_spectrum = _p_peptide_evidence->getQualifiedMassSpectrum(false);
+    }
+  catch(pappso::ExceptionNotFound &notfound)
+    {
+      // mz file not found, we can not get the qualified mass spectrum
+      return;
+    }
+  qDebug();
+  QVariant ion_mobility_begin = mass_spectrum.getParameterValue(
+    pappso::QualifiedMassSpectrumParameter::OneOverK0begin);
+  qDebug();
+  if(!ion_mobility_begin.isNull())
+    {
+      qDebug();
+      ui->ion_mobility_form_widget->show();
+      ui->ion_mobility_line->show();
+
+      QString im_begin_val =
+        QString::number(ion_mobility_begin.toDouble(), 'f', 3);
+      QString im_end_val = QString::number(
+        mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::OneOverK0end)
+          .toDouble(),
+        'f',
+        3);
+      ui->ion_mobility_begin_value->setText(im_begin_val + " 1/K0");
+      ui->ion_mobility_end_value->setText(im_end_val + " 1/K0");
+
+      ui->collision_label->setText(QString("%1 eV").arg(
+        mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::CollisionEnergy)
+          .toInt()));
+    }
+
+  qDebug();
+}
+
 
 void
 PeptideWindow::chooseDefaultMzDataDir()
@@ -331,7 +403,7 @@ PeptideWindow::chooseDefaultMzDataDir()
   ui->mz_data_dir_label->setText(path);
 
 
-  qDebug() << "PeptideWindow::chooseDefaultMzDataDir begin";
+  qDebug() << "begin";
   ui->file_not_found->setVisible(false);
   ui->xic_button->setEnabled(true);
   ui->spectrum_widget->setVisible(true);
@@ -352,7 +424,7 @@ PeptideWindow::openInPeptideViewer()
             << _p_peptide_evidence->getMsRunP()->getFileName()
             << QString("%1").arg(_p_peptide_evidence->getScanNumber());
 
-  qDebug() << "PeptideWindow::openInPeptideViewer " << program << " "
+  qDebug()  << program << " "
            << arguments.join(" ");
   QProcess *myProcess = new QProcess(this);
   myProcess->start(program, arguments);
@@ -370,8 +442,7 @@ PeptideWindow::doSpectrumSpReady(pappso::MassSpectrumCstSPtr spectrum_sp,
                                  QString error,
                                  QString fatal_error)
 {
-  qDebug() << "PeptideWindow::doSpectrumSpReady begin error=" << error
-           << " fatal_error=" << fatal_error;
+  qDebug() << "begin error=" << error << " fatal_error=" << fatal_error;
   mp_status_label->clear();
   _mz_label->clear();
   if((error.isEmpty()) && (fatal_error.isEmpty()))
@@ -382,9 +453,10 @@ PeptideWindow::doSpectrumSpReady(pappso::MassSpectrumCstSPtr spectrum_sp,
 
       ui->spectrum_widget->setMsLevel(2);
       ui->spectrum_widget->setMassSpectrumCstSPtr(spectrum_sp);
-      qDebug() << "PeptideWindow::doSpectrumSpReady plot";
+      qDebug() << "plot";
       ui->spectrum_widget->plot();
-      qDebug() << "PeptideWindow::doSpectrumSpReady rescale";
+      ui->spectrum_widget->highlightPrecursorPeaks();
+      qDebug() << "rescale";
       ui->spectrum_widget->rescale();
       _spectrum_is_ready = true;
     }
@@ -420,54 +492,54 @@ PeptideWindow::doSpectrumSpReady(pappso::MassSpectrumCstSPtr spectrum_sp,
       ui->spectrum_widget->setVisible(false);
       _spectrum_is_ready = false;
     }
-  qDebug() << "PeptideWindow::doSpectrumSpReady end";
+  updateDisplay();
+  qDebug() << "end";
 }
 
 void
 PeptideWindow::setPeptideEvidence(PeptideEvidence *p_peptide_evidence)
 {
-  qDebug() << "PeptideWindow::setPeptideEvidence begin " << p_peptide_evidence;
+  qDebug() << "begin " << p_peptide_evidence;
   _p_peptide_evidence = p_peptide_evidence;
   _spectrum_is_ready  = false;
 
-  qDebug() << "PeptideWindow::setPeptideEvidence 1";
+  qDebug() << "1";
 
   ui->file_not_found->setVisible(false);
   ui->spectrum_widget->setVisible(true);
   mp_status_label->setText("loading spectrum");
 
-  qDebug() << "PeptideWindow::setPeptideEvidence 2";
+  qDebug() << "2";
   pappso::PeptideSp peptide = _p_peptide_evidence->getPeptideXtpSp();
-  qDebug() << "PeptideWindow::setPeptideEvidence 3";
+  qDebug() << "3";
   ui->spectrum_widget->setMs2Precision(_p_precision);
   ui->spectrum_widget->setPeptideCharge(_p_peptide_evidence->getCharge());
   ui->spectrum_widget->setPeptideSp(peptide);
 
-  qDebug() << "PeptideWindow::setPeptideEvidence 4";
+  qDebug() << "4";
   // ui->spectrum_widget->plot();
 
   updateDisplay();
-  qDebug() << "PeptideWindow::setPeptideEvidence emit "
+  qDebug() << " emit "
               "loadSpectrumSp(_p_peptide_match)";
   emit loadSpectrumSp(_p_peptide_evidence);
-  qDebug() << "PeptideWindow::setPeptideEvidence end";
+  qDebug() << "end";
 }
 
 void
 PeptideWindow::doMsmsPrecisionChanged(pappso::PrecisionPtr precision)
 {
 
-  qDebug() << "PeptideWindow::doMsmsPrecisionChanged begin "
-           << precision->toString();
+  qDebug() << "begin " << precision->toString();
   QSettings settings;
   _p_precision = precision;
   ui->spectrum_widget->setMs2Precision(_p_precision);
-  qDebug() << "PeptideWindow::doMsmsPrecisionUnitChanged plot ";
+  qDebug() << " plot ";
   ui->spectrum_widget->plot();
 
   settings.setValue("peptideview/precision", precision->toString());
 
-  qDebug() << "PeptideWindow::doMsmsPrecisionUnitChanged end ";
+  qDebug() << "end ";
 }
 
 void
@@ -530,3 +602,21 @@ PeptideWindow::doProjectNameChanged(QString name)
 {
   setWindowTitle(tr("%1 - Peptide details").arg(name));
 }
+
+bool
+PeptideWindow::checkPeptideViewerWorking()
+{
+  QSettings settings;
+  QString program =
+    settings.value("application/peptideviewer", "/usr/bin/pt-peptideviewer")
+      .toString();
+  QFileInfo program_info = QFileInfo(program);
+  if(program_info.exists())
+    {
+      if(program_info.isExecutable())
+        {
+          return true;
+        }
+    }
+  return false;
+}
