@@ -35,14 +35,14 @@
 #include "../../core/labeling/labelingmethod.h"
 #include "../../utils/utils.h"
 #include <qcustomplot.h>
-#include "../../core/qvalue/computeqvalues.h"
 #include "gui/lists/ms_identification_run_list_view/msidentificationlistwindow.h"
 #include "gui/lists/ms_identification_run_list_view/engine_detail_view/enginedetailwindow.h"
+#include "../../core/qvalue/computeqvalues.h"
 
 ProjectWindow::ProjectWindow(MainWindow *parent)
   : QMainWindow(parent), ui(new Ui::ProjectView)
 {
-  main_window = parent;
+  mp_mainWindow = parent;
 
   ui->setupUi(this);
   //   WorkerThread *p_worker = new WorkerThread(this);
@@ -95,7 +95,7 @@ ProjectWindow::ProjectWindow(MainWindow *parent)
           &EditLabelMethods::accepted,
           this,
           &ProjectWindow::doAcceptedLabelingMethod);
-  connect(main_window,
+  connect(mp_mainWindow,
           &MainWindow::projectNameChanged,
           this,
           &ProjectWindow::doProjectNameChanged);
@@ -103,13 +103,13 @@ ProjectWindow::ProjectWindow(MainWindow *parent)
           &ProjectWindow::projectStatusChanged,
           this,
           &ProjectWindow::doProjectStatusChanged);
-  connect(main_window->getWorkerThread(),
+  connect(mp_mainWindow->getWorkerThread(),
           &WorkerThread::bestMsrunForAlignmentGroupFinished,
           this,
           &ProjectWindow::doBestMsRunForAlignmentFinished);
   connect(this,
           &ProjectWindow::operateMassChroqExportDialog,
-          main_window,
+          mp_mainWindow,
           &MainWindow::doActionMassChroQ);
 
   //
@@ -120,7 +120,7 @@ ProjectWindow::ProjectWindow(MainWindow *parent)
           main_window->getWorkerThread(),
           &WorkerThread::doGrouping);
           */
-  main_window->getWorkerThread()->connectProjectWindow(this);
+  mp_mainWindow->getWorkerThread()->connectProjectWindow(this);
 
   this->setDisabled(true);
 }
@@ -141,18 +141,24 @@ ProjectWindow::~ProjectWindow()
   qDebug();
   delete _p_waiting_message_dialog;
   qDebug();
+
+
+  if(mpa_deepProtGui != nullptr)
+    {
+      delete mpa_deepProtGui;
+    }
 }
 
 Project *
 ProjectWindow::getProjectP()
 {
-  return _project_sp.get();
+  return msp_project.get();
 }
 
 ProjectSp
 ProjectWindow::getProjectSP()
 {
-  return _project_sp;
+  return msp_project;
 }
 
 void
@@ -304,7 +310,7 @@ ProjectWindow::computeFdr()
       std::size_t total_psm     = 0;
       std::size_t false_psm     = 0;
       for(IdentificationGroup *identification_group :
-          _project_sp.get()->getIdentificationGroupList())
+          msp_project.get()->getIdentificationGroupList())
         {
           total_prot += identification_group->countProteinMatch(state);
           false_prot += identification_group->countDecoyProteinMatch(state);
@@ -357,7 +363,7 @@ ProjectWindow::computeMassPrecision()
         }
 
       for(IdentificationGroup *identification_group :
-          _project_sp.get()->getIdentificationGroupList())
+          msp_project.get()->getIdentificationGroupList())
         {
           identification_group->collectMhDelta(delta_list, unit, state);
         }
@@ -492,11 +498,17 @@ ProjectWindow::doDisplayLoadingMessage(QString message)
 void
 ProjectWindow::doDisplayLoadingMessagePercent(QString message, int value)
 {
-  qDebug() << "ProjectWindow::doDisplayLoadingMessagePercent " << message << " "
-           << value;
+  qDebug() << message << " " << value;
   _p_waiting_message_dialog->message(message, value);
 }
 
+void
+ProjectWindow::doDisplayLoadingPercent(int value)
+{
+  qDebug() << value;
+  _p_waiting_message_dialog->percent(value);
+}
+
 void
 ProjectWindow::doGroupingFinished()
 {
@@ -505,7 +517,7 @@ ProjectWindow::doGroupingFinished()
 
   // re group
   for(IdentificationGroup *p_ident_group :
-      _project_sp.get()->getIdentificationGroupList())
+      msp_project.get()->getIdentificationGroupList())
     {
       refreshGroup(p_ident_group);
     }
@@ -549,6 +561,16 @@ ProjectWindow::doViewPeptideList(IdentificationGroup *p_ident_group,
   qDebug() << "ProjectWindow::doViewPeptideList end";
 }
 
+
+void
+ProjectWindow::doViewPeptideEvidenceSpDetail(
+  std::shared_ptr<PeptideEvidence> peptide_evidence_sp)
+{
+  m_memoryGuardPeptideEvidenceList.push_back(peptide_evidence_sp);
+  doViewPeptideDetail(peptide_evidence_sp.get());
+}
+
+
 void
 ProjectWindow::doViewPeptideDetail(PeptideEvidence *peptide_evidence)
 {
@@ -723,7 +745,7 @@ ProjectWindow::doViewMsIdentificationList()
 
   qDebug();
 
-  auto identification_list = _project_sp.get()
+  auto identification_list = msp_project.get()
                                ->getIdentificationDataSourceStore()
                                .getIdentificationDataSourceList();
   _p_current_ms_identification_list_window->setIdentificationDataSourceSpList(
@@ -737,17 +759,17 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
 {
   qDebug();
 
-  if(project_sp.get() == _project_sp.get())
+  if(project_sp.get() == msp_project.get())
     return;
 
-  _project_sp = project_sp;
-  ui->contaminant_widget->getProjectContaminants(_project_sp.get());
-  ui->decoy_widget->getProjectDecoys(_project_sp.get());
+  msp_project = project_sp;
+  ui->contaminant_widget->getProjectContaminants(msp_project.get());
+  ui->decoy_widget->getProjectDecoys(msp_project.get());
 
 
   qDebug() << " project getFastaFileList size="
-           << _project_sp.get()->getFastaFileStore().getFastaFileList().size();
-  _fastafile_list = _project_sp.get()->getFastaFileStore().getFastaFileList();
+           << msp_project.get()->getFastaFileStore().getFastaFileList().size();
+  _fastafile_list = msp_project.get()->getFastaFileStore().getFastaFileList();
 
   for(auto &&p_window : _ptm_island_list_window_collection)
     {
@@ -791,7 +813,7 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
     }
 
   std::vector<IdentificationGroup *> identification_list =
-    _project_sp.get()->getIdentificationGroupList();
+    msp_project.get()->getIdentificationGroupList();
 
 
   doViewProteinList(identification_list[0]);
@@ -859,7 +881,7 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
     }
 
   AutomaticFilterParameters params =
-    _project_sp.get()->getAutomaticFilterParameters();
+    msp_project.get()->getAutomaticFilterParameters();
 
   ui->filter_parameter_widget->setAutomaticFilterParameters(params);
   //_protein_list_window->setIdentificationGroup(_project_sp.get()->getCurrentIdentificationGroupP());
@@ -868,6 +890,45 @@ ProjectWindow::setProjectSp(ProjectSp project_sp)
   refresh();
   this->setEnabled(true);
 
+  qDebug();
+  // check DeepProt engine to enable/disable dedicated GUI
+  bool hasDeepProt = false;
+  for(auto &identification_date_source : msp_project.get()
+                                           ->getIdentificationDataSourceStore()
+                                           .getIdentificationDataSourceList())
+    {
+      if(identification_date_source.get()->getIdentificationEngine() ==
+         IdentificationEngine::DeepProt)
+        {
+          hasDeepProt = true;
+          break;
+        }
+    }
+
+  qDebug();
+  if(hasDeepProt)
+    {
+      qDebug();
+      if(mpa_deepProtGui != nullptr)
+        {
+          delete mpa_deepProtGui;
+          mpa_deepProtGui = nullptr;
+        }
+      if(mpa_deepProtGui == nullptr)
+        {
+          mpa_deepProtGui = new DeepProtGui(this, msp_project);
+          qDebug();
+        }
+    }
+  else
+    {
+
+      if(mpa_deepProtGui != nullptr)
+        {
+          delete mpa_deepProtGui;
+          mpa_deepProtGui = nullptr;
+        }
+    }
   qDebug();
   // doAutomaticFilterParametersChanged(params);
   // doFdrChanged();
@@ -876,24 +937,28 @@ void
 ProjectWindow::doIdentificationsComboboxChanged(int index_in)
 {
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
-  for(int index = 0; index < ui->identifications_combobox->count(); index++)
+  qDebug();
+  if(ui->identifications_combobox->isVisible())
     {
+      for(int index = 0; index < ui->identifications_combobox->count(); index++)
+        {
+          qobject_cast<IdentificationGroupWidget *>(
+            qvariant_cast<QObject *>(
+              ui->identifications_combobox->itemData(index)))
+            ->setVisible(false);
+        }
       qobject_cast<IdentificationGroupWidget *>(
-        qvariant_cast<QObject *>(ui->identifications_combobox->itemData(index)))
-        ->setVisible(false);
+        qvariant_cast<QObject *>(
+          ui->identifications_combobox->itemData(index_in)))
+        ->setVisible(true);
     }
-  qobject_cast<IdentificationGroupWidget *>(
-    qvariant_cast<QObject *>(ui->identifications_combobox->itemData(index_in)))
-    ->setVisible(true);
-
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 void
 ProjectWindow::editModifications()
 {
-  _p_edit_modifications->setProjectSp(_project_sp);
+  _p_edit_modifications->setProjectSp(msp_project);
   _p_edit_modifications->show();
   _p_edit_modifications->raise();
   _p_edit_modifications->activateWindow();
@@ -902,12 +967,23 @@ ProjectWindow::editModifications()
 void
 ProjectWindow::editLabelingMethods()
 {
-  _p_edit_label_methods->setProjectSp(_project_sp);
+  _p_edit_label_methods->setProjectSp(msp_project);
   _p_edit_label_methods->show();
   _p_edit_label_methods->raise();
   _p_edit_label_methods->activateWindow();
 }
 
+void
+ProjectWindow::deepProtPostProcessInterface()
+{
+  if(mpa_deepProtGui != nullptr)
+    {
+      mpa_deepProtGui->show();
+      mpa_deepProtGui->raise();
+      mpa_deepProtGui->activateWindow();
+    }
+}
+
 void
 ProjectWindow::hideWaitingMessage()
 {
@@ -933,8 +1009,8 @@ ProjectWindow::doIdentificationGroupEdited(
   qDebug() << "begin";
   emit operateGroupingOnIdentification(
     p_identification_group,
-    _project_sp.get()->getContaminantRemovalMode(),
-    _project_sp.get()->getGroupingType());
+    msp_project.get()->getContaminantRemovalMode(),
+    msp_project.get()->getGroupingType());
 }
 
 void
@@ -954,13 +1030,13 @@ ProjectWindow::doAcceptedLabelingMethod()
 
   LabelingMethodSp labeling_method_sp =
     _p_edit_label_methods->getLabelingMethodSp();
-  _project_sp.get()->setLabelingMethodSp(labeling_method_sp);
+  msp_project.get()->setLabelingMethodSp(labeling_method_sp);
   //_p_edit_label_methods->applyLabelingMethodInProject();
 
   doDisplayLoadingMessage(tr("labeling peptides"));
 
   qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
-  emit operateGrouping(_project_sp);
+  emit operateGrouping(msp_project);
 }
 
 
@@ -1000,16 +1076,18 @@ ProjectWindow::doApplyDecoy()
 
       doDisplayLoadingMessage(tr("tagging decoy proteins"));
 
-      ui->decoy_widget->setProjectDecoys(_project_sp.get());
+      ui->decoy_widget->setProjectDecoys(msp_project.get());
       // doDisplayLoadingMessage(tr("updating FDR"));
       //_project_sp.get()->updateAutomaticFilters(automatic_filter);
       doDisplayLoadingMessage(tr("updating filters"));
-      _project_sp.get()->updateAutomaticFilters(
-        _project_sp.get()->getAutomaticFilterParameters());
+      msp_project.get()->updateAutomaticFilters(
+        msp_project.get()->getAutomaticFilterParameters());
 
 
       qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
-      emit operateGrouping(_project_sp);
+
+      emit filterChangeFinished();
+      emit operateGrouping(msp_project);
       emit projectStatusChanged();
     }
   catch(pappso::PappsoException &exception_pappso)
@@ -1035,10 +1113,10 @@ ProjectWindow::doComputePsmQvalues()
       showWaitingMessage(tr("Computing q-values on PSM"));
 
 
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      qDebug();
 
-      ComputeQvalues values(_project_sp);
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      ComputeQvalues values(msp_project.get());
+      qDebug();
       hideWaitingMessage();
     }
   catch(pappso::PappsoException &exception_pappso)
@@ -1068,15 +1146,16 @@ ProjectWindow::doApplyFilter()
 
       doDisplayLoadingMessage(tr("tagging contaminant proteins"));
 
-      ui->contaminant_widget->setProjectContaminants(_project_sp.get());
+      ui->contaminant_widget->setProjectContaminants(msp_project.get());
       doDisplayLoadingMessage(tr("updating filters"));
       qDebug();
-      _project_sp.get()->updateAutomaticFilters(automatic_filter);
+      msp_project.get()->updateAutomaticFilters(automatic_filter);
 
       qDebug();
       hideWaitingMessage();
       qDebug();
-      emit operateGrouping(_project_sp);
+      emit filterChangeFinished();
+      emit operateGrouping(msp_project);
       emit projectStatusChanged();
     }
   catch(pappso::PappsoException &exception_pappso)
@@ -1102,20 +1181,20 @@ ProjectWindow::doProjectNameChanged(QString name)
 void
 ProjectWindow::doProjectStatusChanged()
 {
-  _project_sp.get()->setProjectChangedStatus();
+  msp_project.get()->setProjectChangedStatus(true);
 }
 
 void
 ProjectWindow::doBestMsRunForAlignmentFinished(MsRunSp msrun_sp)
 {
-  main_window->hideWaitingMessage();
+  mp_mainWindow->hideWaitingMessage();
   emit bestMsRunFound(msrun_sp);
 }
 
 PtmMode
 ProjectWindow::getPtmMode()
 {
-  PtmMode ptm_mode = _project_sp.get()->getPtmMode();
+  PtmMode ptm_mode = msp_project.get()->getPtmMode();
 
   if(ptm_mode == PtmMode::none)
     {
@@ -1128,9 +1207,9 @@ ProjectWindow::getPtmMode()
 void
 ProjectWindow::doCleanMsRunReaders()
 {
-  if(_project_sp.get() != nullptr)
+  if(msp_project.get() != nullptr)
     {
-      for(MsRunSp ms_run_sp : _project_sp.get()->getMsRunStore().getMsRunList())
+      for(MsRunSp ms_run_sp : msp_project.get()->getMsRunStore().getMsRunList())
         {
           qDebug() << "free reader of " << ms_run_sp.get()->getFileName();
           ms_run_sp.get()->freeMsRunReaderSp();
@@ -1159,3 +1238,16 @@ ProjectWindow::doExportXicAreaToCsvFinished()
   hideWaitingMessage();
   qDebug() << "Export Finished";
 }
+
+void
+ProjectWindow::enableDeepProtStudio(bool enabled)
+{
+  mp_mainWindow->enableDeepProtStudio(enabled);
+}
+
+void
+ProjectWindow::doShowStopButton()
+{
+  qDebug();
+  _p_waiting_message_dialog->showStopButton();
+}
