@@ -1,3 +1,7 @@
+/** @file src/gui/project_view/projectwindow.h
+ *
+ * project centric GUI
+ */
 
 /*******************************************************************************
  * Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
@@ -38,6 +42,7 @@
 #include <qcustomplot.h>
 #include "../lists/ms_identification_run_list_view/msidentificationlistwindow.h"
 #include "../lists/ms_identification_run_list_view/engine_detail_view/enginedetailwindow.h"
+#include "../edit/deepprot_gui/deepprotgui.h"
 
 class MainWindow;
 
@@ -61,18 +66,36 @@ class ProjectWindow : public QMainWindow
   Project *getProjectP();
   void setProjectSp(ProjectSp project_sp);
   ProjectSp getProjectSP();
+
+  /** @brief Open a new window to edit modifications
+   */
   void editModifications();
+
+  /** @brief Open a new window to edit labeling methods
+   */
   void editLabelingMethods();
+
+  /** @brief Open a new window dedicated to DeepProt post process
+   */
+  void deepProtPostProcessInterface();
+
   void openInXicViewer(const PeptideEvidence *p_peptide_evidence);
   void popEngineDetailView();
   ~ProjectWindow();
 
+  /** @brief enable or disable DeepProt studio feature
+   */
+  void enableDeepProtStudio(bool enabled);
+
+  /** @brief Open a new window dedicated to view used engine parameters
+   */
+  void doViewEngineDetail(IdentificationDataSourceSp *identificationEngine);
+
   public slots:
   void doViewPtmIslandList(IdentificationGroup *p_identification_group);
   void doPtmIslandGrouping(IdentificationGroup *p_identification_group);
   void doViewProteinList(IdentificationGroup *p_identification_group = nullptr);
   void doViewMsIdentificationList();
-  void doViewEngineDetail(IdentificationDataSourceSp *identificationEngine);
   void setDefaultProteinListWindow(ProteinListWindow *p_protein_list_window);
   void doAutomaticFilterParametersChanged(AutomaticFilterParameters parameters);
   void doMassPrecisionUnitChanged(QString combo_value);
@@ -82,10 +105,17 @@ class ProjectWindow : public QMainWindow
   void doIdentificationsComboboxChanged(int index);
   void doDisplayLoadingMessage(QString message);
   void doDisplayLoadingMessagePercent(QString message, int value);
+  void doDisplayLoadingPercent(int value);
   void refreshGroup(IdentificationGroup *p_ident_group);
   void refreshPtmGroup(IdentificationGroup *p_ident_group);
   void doAcceptedLabelingMethod();
   void doViewPeptideDetail(PeptideEvidence *peptide_evidence);
+
+  /** @brief ask to view peptide detail (MS2 annotated spectrum)
+   * this function takes a shared pointer, more safe memory usage
+   */
+  void doViewPeptideEvidenceSpDetail(
+    std::shared_ptr<PeptideEvidence> peptide_evidence_sp);
   void doFilterChanged();
   void doApplyFilter();
   void doApplyDecoy();
@@ -97,6 +127,7 @@ class ProjectWindow : public QMainWindow
   void doOpenMassChroQDialog();
   void doExportXicAreaToCsv(QString filename, std::vector<XicBox *> xic_boxs);
   void doExportXicAreaToCsvFinished();
+  void doShowStopButton();
   // void setColor(const QColor &color);
   // void setShape(Shape shape);
 
@@ -122,6 +153,9 @@ class ProjectWindow : public QMainWindow
                                 QString project_name,
                                 std::vector<XicBox *> xic_boxs);
 
+  // @brief emit this when peptide/protein filters are done (finished)
+  void filterChangeFinished();
+
   protected:
   void doViewPeptideList(IdentificationGroup *p_ident_group,
                          ProteinMatch *protein_match);
@@ -155,7 +189,10 @@ class ProjectWindow : public QMainWindow
   //   QThread _worker_thread;
   Ui::ProjectView *ui;
   QWidget *_p_identification_widget = nullptr;
-  MainWindow *main_window;
+
+  /** @brief pointer on the main window
+   */
+  MainWindow *mp_mainWindow;
   std::list<ProteinListWindow *> _protein_list_window_collection;
   ProteinListWindow *_p_current_protein_list_window = nullptr;
   std::list<MsIdentificationListWindow *>
@@ -178,9 +215,14 @@ class ProjectWindow : public QMainWindow
   EditLabelMethods *_p_edit_label_methods  = nullptr;
   XicWindow *_p_xic_window                 = nullptr;
 
-  ProjectSp _project_sp;
+  ProjectSp msp_project;
 
   std::vector<FastaFileSp> _fastafile_list;
   WaitingMessageDialog *_p_waiting_message_dialog;
+
+  DeepProtGui *mpa_deepProtGui = nullptr;
   // QCPBars *_p_bars;
+
+  std::vector<std::shared_ptr<PeptideEvidence>>
+    m_memoryGuardPeptideEvidenceList;
 };
