@@ -425,6 +425,10 @@ TandemRunDialog::selectTdfFolder()
           directories_names = directories_dialog.selectedFiles();
         }
 
+      for(QString dirnames : directories_names)
+        {
+          qDebug() << dirnames;
+        }
       if(directories_names.size() > 1)
         {
           settings.setValue("path/tandemrun_tdf_directory",
@@ -450,15 +454,20 @@ TandemRunDialog::selectTdfFolder()
           // Use the MGF file for identification
           for(QString &directory_name : directories_names)
             {
-              QDir dir = QDir(directory_name);
-
-              QStringList filters;
-              filters << "*.mgf";
-              dir.setNameFilters(filters);
-              QFileInfoList results = dir.entryInfoList(dir.nameFilters());
+              qDebug() << directory_name;
+              QFileInfoList files = QDir(directory_name).entryInfoList();
+              QStringList results;
+              for(QFileInfo file : files)
+                {
+                  if(Utils::guessDataFileFormatFromFile(
+                       file.absoluteFilePath()) == pappso::MzFormat::MGF)
+                    {
+                      results.append(file.absoluteFilePath());
+                    }
+                }
               qDebug() << results;
 
-              if(results.size() == 0)
+              if(results.isEmpty())
                 {
                   throw pappso::PappsoException(
                     tr("The directory %1/ does not contain the mandatory "
@@ -469,12 +478,12 @@ TandemRunDialog::selectTdfFolder()
                 {
                   throw pappso::PappsoException(
                     tr("The directory %1/ contains multiple mgf files\nPlease "
-                       "correct the ambigous situation\n")
+                       "correct the ambiguous situation\n")
                       .arg(directory_name));
                 }
               else
                 {
-                  directory_name = results[0].absoluteFilePath();
+                  directory_name = results[0];
                 }
             }
 
@@ -487,6 +496,7 @@ TandemRunDialog::selectTdfFolder()
           // Use analysis.tdf file for identification
           for(QString &directory_name : directories_names)
             {
+              qDebug() << directory_name;
               directory_name = directory_name + "/analysis.tdf";
               if(!QFileInfo(directory_name).exists())
                 {
@@ -619,7 +629,7 @@ TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
                   settings.setValue("path/tandem_bin", "");
                   throw new pappso::PappsoException(
                     "X!TandemPipeline is not X!Tandem. Please install "
-                    "tandem.exe from https://www.thegpm.org/tandem/ on your "
+                    "tandem.exe from https://www.thegpm.org/TANDEM/ on your "
                     "computer and select the tandem.exe binary");
                 }
               ui->tandem_version_label->setText(
@@ -634,7 +644,7 @@ TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
               if(popup_firefox)
                 {
                   QDesktopServices::openUrl(
-                    QUrl("https://www.thegpm.org/tandem/"));
+                    QUrl("https://www.thegpm.org/TANDEM/"));
                 }
               ui->exe_group_widget->setHidden(false);
             }
@@ -643,7 +653,7 @@ TandemRunDialog::fillTandemBinPath(const QString &tandem_bin_path_in,
         {
           if(popup_firefox)
             {
-              QDesktopServices::openUrl(QUrl("https://www.thegpm.org/tandem/"));
+              QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
             }
           QMessageBox::warning(
             this,
@@ -662,7 +672,7 @@ TandemRunDialog::checkXtandemBin()
   QString tandem_install_text =
     "Please check that X!Tandem is "
     "installed on your computer.\nIt is available at "
-    ":\nhttps://www.thegpm.org/tandem/\nOnce it is installed, "
+    ":\nhttps://www.thegpm.org/TANDEM/\nOnce it is installed, "
     "please "
     "set the correct path to the tandem.exe file";
   QFileInfo tandem_bin(tandem_bin_path);
@@ -673,7 +683,7 @@ TandemRunDialog::checkXtandemBin()
         tr("Wrong X!Tandem configuration"),
         tr("X!Tandem .exe file is not set.\n%1").arg(tandem_install_text));
 
-      QDesktopServices::openUrl(QUrl("https://www.thegpm.org/tandem/"));
+      QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
     }
   else
     {
@@ -696,7 +706,7 @@ TandemRunDialog::checkXtandemBin()
                   .arg(tandem_bin.absoluteFilePath())
                   .arg(tandem_install_text));
 
-              QDesktopServices::openUrl(QUrl("https://www.thegpm.org/tandem/"));
+              QDesktopServices::openUrl(QUrl("https://www.thegpm.org/TANDEM/"));
             }
         }
       else
