@@ -52,13 +52,14 @@
 #include "../core/masschroq_run/masschroqcondorprocess.h"
 #include "../output/ods/xicareasheet.h"
 #include "../output/ods/xicinfosheet.h"
+#include "../output/mcqr/mcqrdata.h"
 
 WorkerThread::WorkerThread(MainWindow *p_main_window)
 {
   _p_main_window = p_main_window;
   qDebug();
 
-  _p_work_monitor = new WorkMonitor();
+  _p_work_monitor = new WorkMonitor(p_main_window);
 
   // worker message
   connect(_p_work_monitor,
@@ -70,9 +71,13 @@ WorkerThread::WorkerThread(MainWindow *p_main_window)
           p_main_window,
           &MainWindow::doDisplayLoadingMessagePercent);
   connect(_p_work_monitor,
-          &WorkMonitor::workerAppendText,
+          &WorkMonitor::workerPercent,
           p_main_window,
-          &MainWindow::doWorkerAppendText);
+          &MainWindow::doDisplayLoadingPercent);
+  connect(_p_work_monitor,
+          &WorkMonitor::workerAppendQString,
+          p_main_window,
+          &MainWindow::doWorkerAppendQString);
   connect(_p_work_monitor,
           &WorkMonitor::workerSetText,
           p_main_window,
@@ -150,6 +155,16 @@ WorkerThread::WorkerThread(MainWindow *p_main_window)
           &MainWindow::operateRunningMassChroq,
           this,
           &WorkerThread::doRunningMassChroQ);
+  // Mcqr write
+  connect(p_main_window,
+          &MainWindow::operateWritingMcqrRData,
+          this,
+          &WorkerThread::doWritingMcqrRDataFile);
+  connect(this,
+          &WorkerThread::operateWritingRDataFileFinished,
+          p_main_window,
+          &MainWindow::doWritingRdataFileFinished);
+
   // protic write
   connect(p_main_window,
           &MainWindow::operateWritingProticFile,
@@ -173,6 +188,10 @@ WorkerThread::WorkerThread(MainWindow *p_main_window)
           &MainWindow::operateWritingFastaFile,
           this,
           &WorkerThread::doWritingFastaFile);
+  connect(_p_work_monitor,
+          &WorkMonitor::showStopButton,
+          p_main_window,
+          &MainWindow::doShowStopButton);
 
   qDebug();
 }
@@ -194,6 +213,10 @@ WorkerThread::connectProjectWindow(ProjectWindow *p_project_window)
           &WorkMonitor::workerMessagePercent,
           p_project_window,
           &ProjectWindow::doDisplayLoadingMessagePercent);
+  connect(_p_work_monitor,
+          &WorkMonitor::workerPercent,
+          p_project_window,
+          &ProjectWindow::doDisplayLoadingPercent);
   connect(this,
           &WorkerThread::loadingMessage,
           p_project_window,
@@ -247,6 +270,10 @@ WorkerThread::connectProjectWindow(ProjectWindow *p_project_window)
           &WorkerThread::exportXicToCsvFinished,
           p_project_window,
           &ProjectWindow::doExportXicAreaToCsvFinished);
+  connect(_p_work_monitor,
+          &WorkMonitor::showStopButton,
+          p_project_window,
+          &ProjectWindow::doShowStopButton);
   qDebug();
 }
 
@@ -462,7 +489,8 @@ WorkerThread::doWritingMassChroqFile(QString filename,
       output.write(project_sp);
       output.close();
       emit operationFinished();
-      emit operateWritingMassChroqFileFinished(filename);
+      emit operateWritingMassChroqFileFinished(filename,
+                                               params.alignment_groups);
     }
   catch(pappso::PappsoException &error)
     {
@@ -471,6 +499,60 @@ WorkerThread::doWritingMassChroqFile(QString filename,
     }
 }
 
+void
+WorkerThread::doWritingMcqrRDataFile(McqrExperimentSp mcqr_experiment_sp,
+                                     ProjectSp project_sp)
+{
+  // mcqr_experiment_sp.get()->getRdataFilePath();
+  QString rdata_dir =
+    QFileInfo(mcqr_experiment_sp.get()->getRdataFilePath()).absolutePath();
+  qDebug() << " rdata_path=" << mcqr_experiment_sp.get()->getRdataFilePath();
+  QTemporaryDir *tmp_rdata_dir_p = new QTemporaryDir(rdata_dir + "/output");
+  tmp_rdata_dir_p->setAutoRemove(true);
+
+  if(!tmp_rdata_dir_p->isValid())
+    {
+      throw pappso::PappsoException(
+        QObject::tr(
+          "problem creating Rdata writing temporary directory in %1\n")
+          .arg(rdata_dir));
+    }
+
+  emit loadingMessage(tr("writing MCQR metadata file, please wait"));
+  QString meta_rdata_path    = tmp_rdata_dir_p->path() + "/meta.RData";
+  McqrRdata *mcqr_rdata_meta = new McqrRdata(meta_rdata_path, project_sp);
+  mcqr_rdata_meta->writeMetaDataTable();
+  mcqr_rdata_meta->closeMCQRDataFile();
+
+  emit loadingMessage(tr("writing MCQR summary file, please wait"));
+  QString summary_rdata_path = tmp_rdata_dir_p->path() + "/summary.RData";
+  McqrRdata *summ_mcqr_rdata = new McqrRdata(summary_rdata_path, project_sp);
+  summ_mcqr_rdata->writeExperimentalSummaryTable();
+  summ_mcqr_rdata->closeMCQRDataFile();
+
+  emit loadingMessage(tr("writing MCQR spectral count file, please wait"));
+  QString sc_rdata_path    = tmp_rdata_dir_p->path() + "/sc.RData";
+  McqrRdata *mcqr_rdata_sc = new McqrRdata(sc_rdata_path, project_sp);
+  mcqr_rdata_sc->writeSpectraCountTable();
+  mcqr_rdata_sc->closeMCQRDataFile();
+
+  emit loadingMessage(tr("writing MCQR quantification info file, please wait"));
+  QString quanti_rdata_path    = tmp_rdata_dir_p->path() + "/quanti.RData";
+  McqrRdata *mcqr_rdata_quanti = new McqrRdata(quanti_rdata_path, project_sp);
+  mcqr_rdata_quanti->writeQuantiInfoTable();
+  mcqr_rdata_quanti->closeMCQRDataFile();
+
+  emit loadingMessage(tr("Merging MCQR rdata files, please wait"));
+  QString rscript_path = McqrRdata::createTheMergeRScript(
+    tmp_rdata_dir_p->path(),
+    mcqr_experiment_sp.get()->getRdataFilePath(),
+    mcqr_experiment_sp.get()->getMassChroqMlFilePath());
+  McqrRdata::mergeTheRDataFiles(rscript_path);
+  tmp_rdata_dir_p->remove();
+  // emit operationFinished();
+  emit operateWritingRDataFileFinished(project_sp->getMcqrExperimentSp());
+}
+
 void
 WorkerThread::doWritingMassChroqPrmFile(QString filename, ProjectSp project_sp)
 {
@@ -575,7 +657,7 @@ WorkerThread::doLoadingResults(bool is_individual,
           project_sp.get()->setProjectMode(ProjectMode::combined);
         }
 
-      _p_work_monitor->setProgressMaximumValue(file_list.size());
+      _p_work_monitor->setTotalSteps(file_list.size());
       int i = 0;
       for(QString filename : file_list)
         {
@@ -632,9 +714,16 @@ WorkerThread::doRunningXtandem(TandemRunBatch tandem_run_batch)
     }
   catch(pappso::PappsoException &error)
     {
-      qDebug() << error.qwhat();
-      emit operationFailed(
-        tr("Error while running X!Tandem job :\n%1").arg(error.qwhat()));
+      if(_p_main_window->stopWorkerThread())
+        {
+          _p_work_monitor->canceled(error.qwhat());
+        }
+      else
+        {
+          qDebug() << error.qwhat();
+          emit operationFailed(
+            tr("Error while running X!Tandem job :\n%1").arg(error.qwhat()));
+        }
     }
   qDebug();
 }
@@ -716,7 +805,7 @@ WorkerThread::doFindBestMsrunForAlignment(ProjectSp project_sp,
         tr("looking for the best MSrun reference for alignment, please wait"));
 
       _p_work_monitor->message("checking MS run file path");
-      _p_work_monitor->setProgressMaximumValue(
+      _p_work_monitor->setTotalSteps(
         alignment_group->getMsRunsInAlignmentGroup().size());
 
       checkMsrunFilePath(alignment_group->getMsRunsInAlignmentGroup());
@@ -777,7 +866,7 @@ WorkerThread::doFindBestMsrunForAlignment(ProjectSp project_sp,
 }
 
 void
-WorkerThread::checkMsrunFilePath(std::list<MsRunSp> msruns)
+WorkerThread::checkMsrunFilePath(const std::vector<MsRunSp> &msruns)
 {
   std::size_t i      = 0;
   bool should_i_stop = false;
@@ -813,7 +902,7 @@ WorkerThread::checkMsrunFilePath(std::list<MsRunSp> msruns)
 }
 
 MsRunSp
-WorkerThread::chooseBestMsRun(std::list<MsRunSp> msruns)
+WorkerThread::chooseBestMsRun(const std::vector<MsRunSp> &msruns)
 {
   _p_work_monitor->message("choosing MS run");
 
@@ -874,7 +963,7 @@ WorkerThread::doCheckMsrunFilePath(ProjectSp msp_project)
   try
     {
 
-      _p_work_monitor->setProgressMaximumValue(
+      _p_work_monitor->setTotalSteps(
         msp_project->getIdentificationDataSourceStore()
           .getIdentificationDataSourceList()
           .size());
