@@ -58,8 +58,8 @@ class WorkerThread : public QObject
 
   protected:
   void closeEvent(QCloseEvent *event);
-  void checkMsrunFilePath(std::list<MsRunSp> msruns);
-  MsRunSp chooseBestMsRun(std::list<MsRunSp> msruns);
+  void checkMsrunFilePath(const std::vector<MsRunSp> &msruns);
+  MsRunSp chooseBestMsRun(const std::vector<MsRunSp> &msruns);
 
   public slots:
   void doXpipFileLoad(QString filename);
@@ -71,6 +71,8 @@ class WorkerThread : public QObject
   void doWritingMassChroqFile(QString filename,
                               ProjectSp project_sp,
                               MasschroqFileParameters params);
+  void doWritingMcqrRDataFile(McqrExperimentSp mcqr_experiment_sp,
+                              ProjectSp project_sp);
   void doWritingMassChroqPrmFile(QString filename, ProjectSp project_sp);
   void doWritingProticFile(QString filename, ProjectSp project_sp);
   void doWritingMcqrSpectralCountFile(QString filename, ProjectSp project_sp);
@@ -105,7 +107,10 @@ class WorkerThread : public QObject
   void ptmGroupingOnIdentificationFinished(
     IdentificationGroup *p_identification_group);
   void operationFinished();
-  void operateWritingMassChroqFileFinished(QString masschroqml_file);
+  void operateWritingMassChroqFileFinished(
+    QString masschroqml_file,
+    std::vector<MsRunAlignmentGroupSp> quantified_groups);
+  void operateWritingRDataFileFinished(McqrExperimentSp p_mcqr_experiment);
   void operationFailed(QString error);
   void findingBestMsrunForAlignmentFinished(MsRunSp msrun_sp);
   void bestMsrunForAlignmentGroupFinished(MsRunSp msrun_sp);
