@@ -140,6 +140,14 @@ XicBox::XicBox(XicWindow *parent) : QWidget(parent), ui(new Ui::XicBox)
   // ui->xic_list_widget->setLayout(new QVBoxLayout(ui->xic_list_widget));
   ui->histo_widget->legend->setVisible(true);
 
+  // Set the Loading icon
+  mp_loadingMovie = new QMovie(":icons/resources/icons/icon_wait.gif");
+  //   mp_loadingMovie->setScaledSize(QSize(100, 100));
+  ui->loading_label->setMovie(mp_loadingMovie);
+  mp_loadingMovie->start();
+
+  showLoadingIcon(true);
+
   if(_p_xic_window->isRetentionTimeSeconds())
     {
       ui->xic_widget->setRetentionTimeInSeconds();
@@ -316,7 +324,7 @@ void
 XicBox::setPeptideEvidence(const PeptideEvidence *p_peptide_evidence)
 {
 
-
+  showLoadingIcon(true);
   _p_peptide_evidence = p_peptide_evidence;
   _msrun_sp = p_peptide_evidence->getIdentificationDataSource()->getMsRunSp();
 
@@ -350,6 +358,7 @@ void
 XicBox::setPeptideEvidenceInMsRun(const PeptideEvidence *p_peptide_evidence,
                                   MsRunSp msrun_sp)
 {
+  showLoadingIcon(true);
   _p_peptide_evidence = p_peptide_evidence;
   _msrun_sp           = msrun_sp;
 
@@ -360,7 +369,7 @@ XicBox::setPeptideEvidenceInMsRun(const PeptideEvidence *p_peptide_evidence,
   ui->mz_label->setText(
     QString::number(_p_peptide_evidence->getTheoreticalMz(), 'f', 4));
   ui->msrun_label->setText(QFileInfo(msrun_sp->getFileName()).fileName());
-  ui->msrun_label->setToolTip("Test");
+  ui->msrun_label->setToolTip(msrun_sp->getFileName());
   // get same xic peptide evidence (msrun, peptide, charge)
   // p_projet
   _peptide_evidence_list.clear();
@@ -394,13 +403,52 @@ XicBox::getMsRunSp()
 }
 
 void
-XicBox::setXic(std::vector<pappso::XicCstSPtr> xic_sp_list)
+XicBox::setXic(std::vector<pappso::XicCoordSPtr> xic_sp_list)
 {
-  qDebug() << xic_sp_list.size();
+  qDebug() << xic_sp_list.size() << _natural_isotope_list.size();
   ui->xic_widget->clear();
-  for(std::size_t i = 0; i < xic_sp_list.size(); i++)
+  for(pappso::XicCoordSPtr &xic_coord_sp : xic_sp_list)
     {
-      _natural_isotope_list[i].xic_sp = xic_sp_list[i];
+      //_natural_isotope_list[i].xic_sp = xic_sp_list[i];
+      if(xic_coord_sp.get()->xicSptr == nullptr)
+        {
+          throw pappso::PappsoException(
+            QString(
+              "Error in %1 %2 %3:\nxic_coord_sp.get()->xicSptr == nullptr")
+              .arg(__FILE__)
+              .arg(__FUNCTION__)
+              .arg(__LINE__));
+        }
+      qDebug() << xic_coord_sp.get()->xicSptr.get()->size();
+      if(xic_coord_sp.get()->xicSptr.get()->size() == 0)
+        {
+          throw pappso::PappsoException(
+            QString("Error in %1 %2 "
+                    "%3:\nxic_coord_sp.get()->xicSptr.get()->size() == 0")
+              .arg(__FILE__)
+              .arg(__FUNCTION__)
+              .arg(__LINE__));
+        }
+      bool found = false;
+      for(XicBoxNaturalIsotope &xic_isotope : _natural_isotope_list)
+        {
+          if(xic_isotope.xic_sp.get() == xic_coord_sp.get()->xicSptr.get())
+            {
+              found = true;
+            }
+        }
+
+      if(found == false)
+        { /*
+           throw pappso::PappsoException(
+             QString(
+               "Error in %1 %2 %3:\nthis is not the result we are waiting for")
+               .arg(__FILE__)
+               .arg(__FUNCTION__)
+               .arg(__LINE__));*/
+          // this is not the result we are waiting for
+          return;
+        }
     }
   // pappso::XicWidget * xic_widget = new pappso::XicWidget(this);
   // ui->xic_list_widget->layout()->addWidget(xic_widget);
@@ -409,10 +457,15 @@ XicBox::setXic(std::vector<pappso::XicCstSPtr> xic_sp_list)
       // qDebug() << "XicBox::setXic xic " << xic_isotope.xic_sp.get();
       if(xic_isotope.xic_sp.get() == nullptr)
         {
-          throw new pappso::PappsoException(
+          throw pappso::PappsoException(
             "Error in XicBox::setXic:\n xic_isotope.xic_sp.get() == nullptr");
         }
       qDebug() << xic_isotope.xic_sp.get()->size();
+      if(xic_isotope.xic_sp.get()->size() == 0)
+        {
+          throw pappso::PappsoException(
+            "Error in XicBox::setXic:\n xic_isotope.xic_sp.get()->size() == 0");
+        }
       ui->xic_widget->addXicSp(xic_isotope.xic_sp);
       QString isotope_name = QString("+%1").arg(
         xic_isotope.peptide_natural_isotope_sp.get()->getIsotopeNumber());
@@ -467,7 +520,8 @@ XicBox::setXic(std::vector<pappso::XicCstSPtr> xic_sp_list)
         {
           xic_list.clear();
           _p_xic_window->xicDetect(*(xic_isotope.xic_sp.get()), &xic_list);
-          xic_isotope.matched_peak_sp    = xic_list.getMatchedPeak();
+          xic_isotope.matched_peak_sp = xic_list.getMatchedPeak();
+          qDebug() << "size : " << xic_list.getXicPeakList().size();
           xic_isotope.detected_peak_list = xic_list.getXicPeakList();
           ui->xic_widget->addXicPeakList(xic_isotope.xic_sp.get(),
                                          xic_list.getXicPeakList());
@@ -478,10 +532,10 @@ XicBox::setXic(std::vector<pappso::XicCstSPtr> xic_sp_list)
           qDebug() << e.qwhat();
         }
     }
-
   qDebug() << "XicBox::setXic plot";
   ui->xic_widget->plot();
   drawObservedAreaBars(draw_peak_borders);
+  showLoadingIcon(false);
 }
 
 
@@ -526,6 +580,7 @@ XicBox::drawObservedAreaBars(
         {
           if(xic_isotope.contains(observed_peak))
             {
+              qDebug() << "OK";
               peak_to_draw = observed_peak;
             }
         }
@@ -619,19 +674,35 @@ XicBox::setIsotopeMassList(
   std::vector<pappso::PeptideNaturalIsotopeAverageSp> isotope_mass_list)
 {
   _natural_isotope_list.clear();
-  std::vector<pappso::pappso_double> mass_list;
+
+  pappso::XicCoordSPtr xic_coord_ref =
+    _msrun_sp.get()
+      ->getMsRunReaderSPtr()
+      .get()
+      ->newXicCoordSPtrFromSpectrumIndex(
+        _p_peptide_evidence->getSpectrumIndexByScanNumber(),
+        _p_xic_window->getXicExtractPrecision());
+
+  std::vector<pappso::XicCoordSPtr> mass_list;
   for(pappso::PeptideNaturalIsotopeAverageSp &natural_isotope_average :
       isotope_mass_list)
     {
-      mass_list.push_back(natural_isotope_average.get()->getMz());
-      _natural_isotope_list.push_back(
-        {nullptr, natural_isotope_average, nullptr, nullptr, {}});
+      qDebug() << natural_isotope_average.get()->getMz();
+      pappso::XicCoordSPtr xic_coord =
+        xic_coord_ref.get()->initializeAndClone();
+      xic_coord.get()->mzRange =
+        pappso::MzRange(natural_isotope_average.get()->getMz(),
+                        _p_xic_window->getXicExtractPrecision());
+      mass_list.push_back(xic_coord);
+
+      _natural_isotope_list.push_back({xic_coord.get()->xicSptr,
+                                       natural_isotope_average,
+                                       nullptr,
+                                       nullptr,
+                                       {}});
     }
 
-  emit loadXic(_msrun_sp,
-               mass_list,
-               _p_xic_window->getXicExtractPrecision(),
-               pappso::XicExtractMethod::max);
+  emit loadXic(_msrun_sp, mass_list, pappso::XicExtractMethod::max);
 
   // histogram
   if(m_theoreticalRatioBars == nullptr)
@@ -714,16 +785,29 @@ XicBox::reExtractXic()
   qDebug();
   ui->xic_widget->clear();
 
-  std::vector<pappso::pappso_double> mass_list;
-  for(const XicBoxNaturalIsotope &xic_isotope : _natural_isotope_list)
+  pappso::XicCoordSPtr xic_coord_ref =
+    _msrun_sp.get()
+      ->getMsRunReaderSPtr()
+      .get()
+      ->newXicCoordSPtrFromSpectrumIndex(
+        _p_peptide_evidence->getSpectrumIndex(),
+        _p_xic_window->getXicExtractPrecision());
+
+  std::vector<pappso::XicCoordSPtr> mass_list;
+  for(XicBoxNaturalIsotope &xic_isotope : _natural_isotope_list)
     {
-      mass_list.push_back(
-        xic_isotope.peptide_natural_isotope_sp.get()->getMz());
+      pappso::XicCoordSPtr xic_coord =
+        xic_coord_ref.get()->initializeAndClone();
+      xic_coord.get()->mzRange =
+        pappso::MzRange(xic_isotope.peptide_natural_isotope_sp.get()->getMz(),
+                        _p_xic_window->getXicExtractPrecision());
+      mass_list.push_back(xic_coord);
+      xic_isotope.xic_sp = xic_coord.get()->xicSptr;
     }
-  emit loadXic(_msrun_sp,
-               mass_list,
-               _p_xic_window->getXicExtractPrecision(),
-               _p_xic_window->getXicExtractionMethod());
+
+  qDebug();
+  emit loadXic(_msrun_sp, mass_list, pappso::XicExtractMethod::max);
+
   qDebug();
 }
 
@@ -870,3 +954,17 @@ XicBox::getIsotopicFractionDistribution() const
 {
   return ui->isotopic_distribution_spinbox->value();
 }
+
+void
+XicBox::showLoadingIcon(bool loading_status)
+{
+  ui->loading_label->setVisible(loading_status);
+  if(loading_status)
+    {
+      int size = ui->xic_widget->size().rheight() * 0.5;
+      mp_loadingMovie->setScaledSize(QSize(size, size));
+    }
+
+  ui->xic_widget->setVisible(!loading_status);
+  ui->histo_widget->setVisible(!loading_status);
+}
