@@ -163,8 +163,7 @@ XtandemParamSaxHandler::error(const QXmlParseException &exception)
                 .arg(exception.lineNumber())
                 .arg(exception.columnNumber())
                 .arg(exception.message());
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-           << _errorStr;
+  qDebug() << _errorStr;
   return false;
 }
 
@@ -178,8 +177,7 @@ XtandemParamSaxHandler::fatalError(const QXmlParseException &exception)
                 .arg(exception.lineNumber())
                 .arg(exception.columnNumber())
                 .arg(exception.message());
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-           << _errorStr;
+  qDebug() << _errorStr;
   return false;
 }
 
@@ -255,8 +253,7 @@ XtandemParamSaxHandler::endElement_note()
             QObject::tr("Error reading tandem input parameter \"%1\" :\n%2")
               .arg(_current_label)
               .arg(exception.qwhat());
-          qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-                   << _errorStr;
+          qDebug() << _errorStr;
           return false;
         }
     }
