@@ -359,13 +359,14 @@ XtandemSaxHandler::startElement_domain(QXmlAttributes attributes)
     PeptideXtp(attributes.value("seq").simplified()).makePeptideXtpSp();
   _p_peptide_evidence = new PeptideEvidence(
     _sp_msrun.get(),
-    attributes.value("id").simplified().section(".", 0, 0).toUInt());
+    attributes.value("id").simplified().section(".", 0, 0).toUInt(),
+    false);
 
   _p_peptide_evidence->setRetentionTime(_retention_time);
   _p_peptide_evidence->setEvalue(
     attributes.value("expect").simplified().toDouble());
   // qDebug() << "XtandemSaxHandler::startElement_domain evalue "  <<
-  // _p_peptide_match->getEvalue() << " scan " << _p_peptide_match->getScan();
+  // _p_peptide_match->getEvalue() << " scan " << _p_peptide_match->get();
   /*
     pappso::pappso_double xtandem_mhtheoretical =
       attributes.value("mh").simplified().toDouble();
@@ -717,6 +718,43 @@ XtandemSaxHandler::endElement_note()
           qDebug() << _current_note_label;
           _p_identification_data_source->setTimstofMs2CentroidParameters(
             _current_text);
+
+          if((_sp_msrun.get()->getFileName().endsWith(".tdf")) ||
+             (_sp_msrun.get()->getFileName().endsWith(".d")))
+            {
+              // this is a TimsTOF tandem result file : scan numbers are in fact
+              // spectrum index:
+              // we have to notice this
+              _p_identification_data_source->getPeptideEvidenceStore()
+                .ensureSpectrumIndexRef();
+            }
+        }
+      if(_current_note_label == "output, spectrum index")
+        {
+          // TODO in pappsomspp : change tandem output to explicitly tell if we
+          // are dealing with spectrum index
+          qDebug() << _current_note_label;
+
+          if(_current_text == "true")
+            { // this MUST be spectrum index instead of scan numbers
+              _p_identification_data_source->getPeptideEvidenceStore()
+                .ensureSpectrumIndexRef();
+            }
+        }
+      if(_current_note_label == "spectrum, timstof MS2 filters")
+        {
+          qDebug() << _current_note_label;
+          // this is a TimsTOF tandem result file : scan numbers are in fact
+          // spectrum index:
+          // we have to notice this
+          if((_sp_msrun.get()->getFileName().endsWith(".tdf")) ||
+             (_sp_msrun.get()->getFileName().endsWith(".d")))
+            {
+              // this is a TimsTOF tandem result file : scan numbers are in
+              // fact spectrum index: we have to notice this
+              _p_identification_data_source->getPeptideEvidenceStore()
+                .ensureSpectrumIndexRef();
+            }
         }
       //<note label="process, start time">2013:12:20:16:47:19</note>
 
@@ -749,6 +787,7 @@ XtandemSaxHandler::endElement_note()
       </group>
       */
     }
+
   _current_text = "";
   return is_ok;
 }
