@@ -24,26 +24,24 @@
  *     You should have received a copy of the GNU General Public License
  *     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contributors:
- *     Olivier Langella <Olivier.Langella@u-psud.fr> - initial API and
- *implementation
  ******************************************************************************/
 
 #include "xtpxpipsaxhandler.h"
 
 #include <pappsomspp/exception/exceptionnotfound.h>
+#include <pappsomspp/exception/exceptioninterrupted.h>
 #include <cmath>
 #include "../core/peptideevidence.h"
 #include "../utils/peptidestore.h"
 #include "../utils/proteinstore.h"
 
-XtpXpipSaxHandler::XtpXpipSaxHandler(WorkMonitorInterface *p_monitor,
+XtpXpipSaxHandler::XtpXpipSaxHandler(pappso::UiMonitorInterface *p_monitor,
                                      Project *p_project)
   : _p_project(p_project)
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   _p_monitor = p_monitor;
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
 }
 
 XtpXpipSaxHandler::~XtpXpipSaxHandler()
@@ -70,6 +68,12 @@ XtpXpipSaxHandler::startElement(const QString &namespaceURI [[maybe_unused]],
 
   try
     {
+
+      if(_p_monitor->shouldIstop())
+        {
+          throw pappso::ExceptionInterrupted(
+            QObject::tr("XPIP file reading interrupted by the user"));
+        }
       // startElement_group
       if(_tag_stack.size() == 1)
         {
@@ -86,10 +90,9 @@ XtpXpipSaxHandler::startElement(const QString &namespaceURI [[maybe_unused]],
         {
           if(_count_total % 100 == 0)
             {
-              _p_monitor->message(QString("reading protein matches %1 on %2")
-                                    .arg(_count_protein_matches)
-                                    .arg(_total_protein_matches),
-                                  _count_total);
+              _p_monitor->setStatus(QString("reading protein matches %1 on %2")
+                                      .arg(_count_protein_matches)
+                                      .arg(_total_protein_matches));
             }
           is_ok = startElement_protein_match(attributes);
         }
@@ -101,10 +104,9 @@ XtpXpipSaxHandler::startElement(const QString &namespaceURI [[maybe_unused]],
         {
           if(_count_total % 100 == 0)
             {
-              _p_monitor->message(QString("reading proteins %1 on %2")
-                                    .arg(_count_proteins)
-                                    .arg(_total_proteins),
-                                  _count_total);
+              _p_monitor->setStatus(QString("reading proteins %1 on %2")
+                                      .arg(_count_proteins)
+                                      .arg(_total_proteins));
             }
           is_ok = startElement_protein(attributes);
         }
@@ -149,14 +151,25 @@ XtpXpipSaxHandler::startElement(const QString &namespaceURI [[maybe_unused]],
         {
           is_ok = startElement_msrunInAlignmentGroup(attributes);
         }
+      else if(qName == "alignment_params")
+        {
+          is_ok = startElement_alignment_param(attributes);
+        }
+      else if(qName == "quanti_params")
+        {
+          is_ok = startElement_quantification_param(attributes);
+        }
+      else if(qName == "masschroq_params")
+        {
+          is_ok = startElement_masschroq_param(attributes);
+        }
       else if(qName == "peptide")
         {
           if(_count_total % 100 == 0)
             {
-              _p_monitor->message(QObject::tr("reading peptide %1 on %2")
-                                    .arg(_count_peptides)
-                                    .arg(_total_peptides),
-                                  _count_total);
+              _p_monitor->setStatus(QObject::tr("reading peptide %1 on %2")
+                                      .arg(_count_peptides)
+                                      .arg(_total_peptides));
             }
           is_ok = startElement_peptide(attributes);
         }
@@ -164,11 +177,10 @@ XtpXpipSaxHandler::startElement(const QString &namespaceURI [[maybe_unused]],
         {
           if(_count_total % 100 == 0)
             {
-              _p_monitor->message(
+              _p_monitor->setStatus(
                 QObject::tr("reading peptide evidence %1 on %2")
                   .arg(_count_peptide_evidences)
-                  .arg(_total_peptide_evidences),
-                _count_total);
+                  .arg(_total_peptide_evidences));
             }
           is_ok = startElement_peptide_evidence(attributes);
         }
@@ -312,13 +324,12 @@ XtpXpipSaxHandler::startElement_contaminants(QXmlAttributes attributes)
 {
   //    <contaminants regexp="^contatruc\|" fasta_id=""/>
 
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  qDebug();
   if(!attributes.value("mode").isEmpty())
     {
       _p_project->setContaminantRemovalMode(
         (ContaminantRemovalMode)attributes.value("mode").toUInt());
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-               << (std::uint8_t)_p_project->getContaminantRemovalMode();
+      qDebug() << (std::uint8_t)_p_project->getContaminantRemovalMode();
     }
 
   QString regexp(attributes.value("regexp"));
@@ -394,7 +405,7 @@ XtpXpipSaxHandler::startElement_counts(QXmlAttributes attributes)
   _total = _total_proteins + _total_peptides + _total_peptide_evidences +
            _total_protein_matches;
 
-  _p_monitor->setProgressMaximumValue((std::size_t)_total);
+  _p_monitor->setTotalSteps(_total);
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   return true;
 }
@@ -612,12 +623,22 @@ XtpXpipSaxHandler::startElement_alignmentGroup(QXmlAttributes attributes)
 {
   msp_alignment_group = std::make_shared<MsRunAlignmentGroup>(
     _p_project, attributes.value("name").simplified());
-  _p_project->addMsRunAlignmentGroupToList(msp_alignment_group);
+  if(attributes.value("name").simplified() == "all_msrun")
+    {
+      _p_project->setAllMsRunAlignmentGroup(msp_alignment_group);
+    }
+  else
+    {
+      _p_project->addMsRunAlignmentGroupToList(msp_alignment_group);
+    }
   QString reference_id = attributes.value("reference").simplified();
   if(reference_id != "")
     {
       msp_alignment_group->setMsRunReference(_map_msruns.at(reference_id));
     }
+
+  msp_alignment_group->setMassChroQRunStatusFromInt(
+    attributes.value("status").toUInt());
   return true;
 }
 
@@ -630,6 +651,75 @@ XtpXpipSaxHandler::startElement_msrunInAlignmentGroup(QXmlAttributes attributes)
   return true;
 }
 
+bool
+XtpXpipSaxHandler::startElement_alignment_param(QXmlAttributes attributes)
+{
+  m_massChroQFileParams.ms2_tendency_half_window =
+    attributes.value("ms2_tendency").toInt();
+  m_massChroQFileParams.ms2_smoothing_half_window =
+    attributes.value("ms2_smoothing").toInt();
+  m_massChroQFileParams.ms1_smoothing_half_window =
+    attributes.value("ms1_smoothing").toInt();
+  if(!attributes.value("time_corrections").simplified().isEmpty())
+    {
+      m_massChroQFileParams.write_alignment_times = true;
+      m_massChroQFileParams.alignment_times_directory =
+        attributes.value("time_corrections").simplified();
+    }
+  else
+    {
+      m_massChroQFileParams.write_alignment_times = false;
+    }
+  return true;
+}
+
+bool
+XtpXpipSaxHandler::startElement_masschroq_param(QXmlAttributes attributes)
+{
+  msp_alignment_group->setMassChroqmlPath(attributes.value("masschroqml"));
+  if(QFileInfo(attributes.value("result")).suffix() == "ods")
+    {
+      m_massChroQFileParams.result_file_format = TableFileFormat::ods;
+    }
+  else
+    {
+      m_massChroQFileParams.result_file_format = TableFileFormat::tsv;
+    }
+
+  if(!attributes.value("compar").isEmpty())
+    {
+      m_massChroQFileParams.export_compar_file = true;
+    }
+  return true;
+}
+
+bool
+XtpXpipSaxHandler::startElement_quantification_param(QXmlAttributes attributes)
+{
+  m_massChroQFileParams.xic_extraction_range =
+    pappso::PrecisionFactory::fromString(attributes.value("xic_range"));
+  if(attributes.value("xic_method").toInt() == 0)
+    {
+      m_massChroQFileParams.xic_extraction_method =
+        pappso::XicExtractMethod::max;
+    }
+  else
+    {
+      m_massChroQFileParams.xic_extraction_method =
+        pappso::XicExtractMethod::sum;
+    }
+
+  ZivyParams zivy;
+  zivy._smoothing_half_window = attributes.value("smoothing").toInt();
+  zivy._minmax_half_window    = attributes.value("minmax_half").toInt();
+  zivy._maxmin_half_window    = attributes.value("maxmin_half").toInt();
+  zivy._minmax_threshold      = attributes.value("minmax_thre").toDouble();
+  zivy._maxmin_threshold      = attributes.value("maxmin_thre").toDouble();
+  msp_alignment_group->setZivyParams(zivy);
+  return true;
+}
+
+
 bool
 XtpXpipSaxHandler::startElement_peptide_evidence_list(QXmlAttributes attributes)
 {
@@ -658,9 +748,27 @@ XtpXpipSaxHandler::startElement_peptide_evidence(QXmlAttributes attributes)
 
             */
 
-  unsigned int scan   = attributes.value("scan").toUInt();
-  _p_peptide_evidence = new PeptideEvidence(
-    _sp_current_identification_source.get()->getMsRunSp().get(), scan);
+
+  if(!attributes.value("scan").isEmpty())
+    {
+      _p_peptide_evidence = new PeptideEvidence(
+        _sp_current_identification_source.get()->getMsRunSp().get(),
+        attributes.value("scan").simplified().toUInt(),
+        false);
+    }
+  if(!attributes.value("idx").isEmpty())
+    {
+      _p_peptide_evidence = new PeptideEvidence(
+        _sp_current_identification_source.get()->getMsRunSp().get(),
+        attributes.value("idx").simplified().toUInt(),
+        true);
+    }
+  if(_p_peptide_evidence == nullptr)
+    {
+      throw pappso::PappsoException(
+        QObject::tr("peptide must define 'scan' or 'idx' attribute"));
+    }
+
   _p_peptide_evidence->setIdentificationDataSource(
     _sp_current_identification_source.get());
 
@@ -756,6 +864,7 @@ XtpXpipSaxHandler::startElement_protein(QXmlAttributes attributes)
 {
 
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+  _p_monitor->count();
   _count_proteins++;
   _count_total++;
   /*
@@ -869,6 +978,8 @@ XtpXpipSaxHandler::endElement_peptide()
 
   _count_peptides++;
   _count_total++;
+
+  _p_monitor->count();
   return true;
 }
 
@@ -879,6 +990,7 @@ XtpXpipSaxHandler::endElement_peptide_evidence()
   _sp_current_peptide_evidence = nullptr;
   _count_peptide_evidences++;
   _count_total++;
+  _p_monitor->count();
 
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   return true;
@@ -896,6 +1008,7 @@ XtpXpipSaxHandler::endElement_msrun()
 bool
 XtpXpipSaxHandler::endElement_alignmentGroup()
 {
+  msp_alignment_group->setMassChroQFileParams(m_massChroQFileParams);
   msp_alignment_group = nullptr;
   return true;
 }
@@ -936,6 +1049,8 @@ XtpXpipSaxHandler::endElement_protein_match()
   _count_total++;
   _current_identification_group_p->addProteinMatch(_p_protein_match);
   _p_protein_match = nullptr;
+
+  _p_monitor->count();
   return true;
 }
 
