@@ -35,9 +35,12 @@ main(int argc, char *argv[])
   QTextStream errorStream(stderr, QIODevice::WriteOnly);
   QApplication app(argc, argv);
 
+  QResource::registerResource("xtpcpp.rcc");
+
   qRegisterMetaType<TandemRunBatch>("TandemRunBatch");
   qRegisterMetaType<std::vector<pappso::pappso_double>>(
     "std::vector<pappso::pappso_double>");
+  qRegisterMetaType<std::size_t>("std::size_t");
   qRegisterMetaType<pappso::PrecisionPtr>("pappso::PrecisionPtr");
   qRegisterMetaType<std::vector<pappso::XicCstSPtr>>(
     "std::vector<pappso::XicCstSPtr>");
@@ -56,6 +59,12 @@ main(int argc, char *argv[])
   qRegisterMetaType<PtmMode>("PtmMode");
   qRegisterMetaType<std::vector<XicBox *>>("<std::vector<XicBox *>>");
   qRegisterMetaType<MassChroQRunBatch>("MassChroQRunBatch");
+  qRegisterMetaType<std::vector<pappso::XicCoordSPtr>>(
+    "std::vector<pappso::XicCoordSPtr>");
+
+  qRegisterMetaType<std::vector<MsRunAlignmentGroupSp>>(
+    "std::vector<MsRunAlignmentGroupSp>");
+  qRegisterMetaType<McqrExperimentSp>("McqrExperimentSp");
 
   // qRegisterMetaType<pappso::PeakIonIsotopeMatch>("pappso::PeakIonIsotopeMatch");
 
@@ -63,7 +72,8 @@ main(int argc, char *argv[])
     {
       QCoreApplication::setOrganizationName("PAPPSO");
       QCoreApplication::setOrganizationDomain("pappso.inra.fr");
-      QCoreApplication::setApplicationName("xtpcpp");
+      QCoreApplication::setApplicationName(SOFTWARE_NAME);
+      QCoreApplication::setApplicationVersion(XTPCPP_VERSION);
       MainWindow window;
       window.show();
 
