@@ -122,7 +122,7 @@ MassChroQml::write(ProjectSp sp_project)
   //<masschroq>
   _output_stream->writeStartElement("masschroq");
   _output_stream->writeAttribute("type", "input");
-  _output_stream->writeAttribute("version", "2.2");
+  _output_stream->writeAttribute("version", "2.4");
   //_output_stream->writeAttribute("creationDate",
   // QDateTime::currentDateTime().toString( Qt::ISODate));
   //_output_stream->writeNamespace("http://www.w3.org/2001/XMLSchema-instance","xsi");
@@ -155,6 +155,9 @@ MassChroQml::write(ProjectSp sp_project)
           case pappso::MzFormat::mzML:
             _output_stream->writeAttribute("format", "mzml");
             break;
+          case pappso::MzFormat::brukerTims:
+            _output_stream->writeAttribute("format", "tdf");
+            break;
           default:
             _output_stream->writeAttribute("format", "mzxml");
         }
@@ -211,6 +214,11 @@ MassChroQml::writeQuantificationResults()
   _output_stream->writeEndElement();
   //<quantification_result output_file="result2"
   //	format="ods" />
+  _output_stream->writeStartElement("quantification_result");
+  _output_stream->writeAttribute(
+    "output_file", "rdata_" + QFileInfo(*_output_file).baseName());
+  _output_stream->writeAttribute("format", "rdata");
+  _output_stream->writeEndElement();
   _output_stream->writeComment(
     "<quantification_result output_file=\"result2\" format=\"ods\" />");
   //<compar_result output_file="compar"
@@ -679,7 +687,7 @@ MassChroQml::writeGroups()
       _output_stream->writeAttribute("id",
                                      group_sp->getMsRunAlignmentGroupName());
       QStringList list;
-      for(MsRunSp &msrun : group_sp->getMsRunsInAlignmentGroup())
+      for(const MsRunSp &msrun : group_sp->getMsRunsInAlignmentGroup())
         {
           list << msrun.get()->getXmlId();
         }
