@@ -29,11 +29,14 @@
  ******************************************************************************/
 
 #include "xpip.h"
-#include "../config.h"
+
 #include <QDateTime>
-#include <pappsomspp/pappsoexception.h>
-#include <pappsomspp/utils.h>
 #include <QDebug>
+#include <QDir>
+#include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/exception/exceptionnotfound.h>
+#include <pappsomspp/utils.h>
+#include "../config.h"
 
 Xpip::Xpip(const QString &out_filename)
 {
@@ -145,8 +148,21 @@ Xpip::write(ProjectSp sp_project)
   _output_stream->writeEndElement();
 
   writeMsrunList(_sp_project.get()->getMsRunStore());
-  writeMsrunAlignementGroupsList(
-    _sp_project.get()->getMsRunAlignmentGroupList());
+
+  // write the MsRun Alignement Groups
+  _output_stream->writeStartElement("msrun_alignment_group_list");
+  int count_group = 0;
+  writeMsrunAlignmentGroup(_sp_project.get()->getAllMsRunAlignmentGroup(),
+                           count_group);
+  count_group++;
+  for(MsRunAlignmentGroupSp alignment_group :
+      _sp_project.get()->getMsRunAlignmentGroupList())
+    {
+      writeMsrunAlignmentGroup(alignment_group, count_group);
+      count_group++;
+    }
+  _output_stream->writeEndElement();
+
   writeIdentificationDataSourceList(
     _sp_project.get()->getIdentificationDataSourceStore());
 
@@ -369,36 +385,120 @@ Xpip::writeMsrunList(const MsRunStore &msrun_store)
 }
 
 void
-Xpip::writeMsrunAlignementGroupsList(
-  const std::vector<MsRunAlignmentGroupSp> alignment_groups)
+Xpip::writeMsrunAlignmentGroup(const MsRunAlignmentGroupSp alignment_group,
+                               int count_group)
 {
-  _output_stream->writeStartElement("msrun_alignment_group_list");
-  for(const MsRunAlignmentGroupSp group : alignment_groups)
+  _output_stream->writeStartElement("msrun_group");
+  _output_stream->writeAttribute("id",
+                                 QString("msrun_group%1").arg(count_group));
+  _output_stream->writeAttribute(
+    "name", alignment_group.get()->getMsRunAlignmentGroupName());
+  MsRunSp reference = alignment_group.get()->getMsRunReference();
+  if(reference != nullptr)
     {
-      qDebug() << "AAAAAAAAAA";
-      _output_stream->writeStartElement("msrun_group");
-      _output_stream->writeAttribute("name",
-                                     group.get()->getMsRunAlignmentGroupName());
-      MsRunSp reference = group.get()->getMsRunReference();
-      if(reference != nullptr)
-        {
-          _output_stream->writeAttribute(
-            "reference", group.get()->getMsRunReference().get()->getXmlId());
-        }
-      else
-        {
-          _output_stream->writeAttribute("reference", "");
-        }
+      _output_stream->writeAttribute(
+        "reference",
+        alignment_group.get()->getMsRunReference().get()->getXmlId());
+    }
+  else
+    {
+      _output_stream->writeAttribute("reference", "");
+    }
+  _output_stream->writeAttribute(
+    "status", QString::number((std::int8_t)alignment_group->getGroupStatus()));
 
-      for(const MsRunSp ms_run : group.get()->getMsRunsInAlignmentGroup())
-        {
-          _output_stream->writeStartElement("grouped_msrun");
-          _output_stream->writeAttribute("id", ms_run.get()->getXmlId());
-          _output_stream->writeEndElement();
-        }
+  // List of msruns in the group
+  _output_stream->writeStartElement("msruns");
+  for(const MsRunSp ms_run : alignment_group.get()->getMsRunsInAlignmentGroup())
+    {
+      _output_stream->writeStartElement("grouped_msrun");
+      _output_stream->writeAttribute("id", ms_run.get()->getXmlId());
       _output_stream->writeEndElement();
     }
   _output_stream->writeEndElement();
+
+  // Params used for the masschroqml or mcq
+  if(alignment_group->getGroupStatus() != AlignmentGroupStatus::created)
+    {
+      _output_stream->writeStartElement("group_params");
+      writeAlignmentGroupParameters(alignment_group);
+      _output_stream->writeEndElement();
+    }
+
+  _output_stream->writeEndElement();
+}
+
+void
+Xpip::writeAlignmentGroupParameters(const MsRunAlignmentGroupSp alignment_group)
+{
+  ZivyParams zivy_params   = alignment_group->getZivyParams();
+  QString masschroqml_path = alignment_group->getMassChroqmlPath();
+  MasschroqFileParameters mcq_file_params =
+    alignment_group->getMassChroQFileParams();
+
+  // Alignment parameters
+  _output_stream->writeStartElement("alignment_params");
+  _output_stream->writeAttribute(
+    "ms2_tendency", QString::number(mcq_file_params.ms2_tendency_half_window));
+  _output_stream->writeAttribute(
+    "ms2_smoothing",
+    QString::number(mcq_file_params.ms2_smoothing_half_window));
+  _output_stream->writeAttribute(
+    "ms1_smoothing",
+    QString::number(mcq_file_params.ms1_smoothing_half_window));
+  if(mcq_file_params.write_alignment_times)
+    {
+      _output_stream->writeAttribute("time_corrections",
+                                     mcq_file_params.alignment_times_directory);
+    }
+  else
+    {
+      _output_stream->writeAttribute("time_corrections", "");
+    }
+  _output_stream->writeEndElement();
+
+  // Quantification parameters
+  _output_stream->writeStartElement("quanti_params");
+  _output_stream->writeAttribute(
+    "xic_range", mcq_file_params.xic_extraction_range->toString());
+  _output_stream->writeAttribute(
+    "xic_method",
+    QString::number((std::int8_t)mcq_file_params.xic_extraction_method));
+  _output_stream->writeAttribute(
+    "smoothing", QString::number(zivy_params._smoothing_half_window));
+  _output_stream->writeAttribute(
+    "minmax_half", QString::number(zivy_params._minmax_half_window));
+  _output_stream->writeAttribute(
+    "maxmin_half", QString::number(zivy_params._maxmin_half_window));
+  _output_stream->writeAttribute(
+    "minmax_thre", QString::number(zivy_params._minmax_threshold));
+  _output_stream->writeAttribute(
+    "maxmin_thre", QString::number(zivy_params._maxmin_threshold));
+  _output_stream->writeEndElement();
+
+  // Masschroq parameters
+  _output_stream->writeStartElement("masschroq_params");
+  _output_stream->writeAttribute("masschroqml", masschroqml_path);
+  QString result_path;
+  QString compar_path;
+  QString file_name = QFileInfo(masschroqml_path).baseName();
+  QString dir_path  = QFileInfo(masschroqml_path).absoluteDir().absolutePath();
+  if(mcq_file_params.result_file_format == TableFileFormat::ods)
+    {
+      result_path = dir_path + "/result_" + file_name + ".ods";
+      compar_path = dir_path + "/compar_" + file_name + ".ods";
+    }
+  else // format == tsv
+    {
+      result_path = dir_path + "/result_" + file_name + ".tsv";
+      compar_path = dir_path + "/compar_" + file_name + ".tsv";
+    }
+  _output_stream->writeAttribute("result", result_path);
+  if(mcq_file_params.export_compar_file)
+    {
+      _output_stream->writeAttribute("compar", compar_path);
+    }
+  _output_stream->writeEndElement();
 }
 
 void
@@ -612,7 +712,7 @@ Xpip::writeIdentificationGroupList()
 void
 Xpip::writePeptideEvidence(const PeptideEvidence *p_peptide_evidence)
 {
-  qDebug() << "Xpip::writePeptideEvidence begin";
+  qDebug() << "begin";
 
   _output_stream->writeStartElement("peptide_evidence");
   QString idp = QString("pe%1").arg(
@@ -631,14 +731,24 @@ Xpip::writePeptideEvidence(const PeptideEvidence *p_peptide_evidence)
   catch(std::out_of_range &exception_std)
     {
       throw pappso::PappsoException(
-        QObject::tr("ERROR in Xpip::writePeptideEvidence peptide %1 not found "
-                    "in map :\n%2")
+        QObject::tr(
+          "ERROR writing peptide evidence : petide sequence %1 not found "
+          "in map :\n%2")
           .arg(p_peptide_evidence->getPeptideXtpSp().get()->toAbsoluteString())
           .arg(exception_std.what()));
     }
-  qDebug() << "Xpip::writePeptideEvidence scan";
-  _output_stream->writeAttribute(
-    "scan", QString("%1").arg(p_peptide_evidence->getScanNumber()));
+  qDebug() << "scan";
+  try
+    {
+      _output_stream->writeAttribute(
+        "idx", QString("%1").arg(p_peptide_evidence->getSpectrumIndex()));
+    }
+  catch(pappso::ExceptionNotFound &exception_not_found)
+    {
+      _output_stream->writeAttribute(
+        "scan", QString("%1").arg(p_peptide_evidence->getScanNumber()));
+    }
+
   writeDoubleAttribute("rt", p_peptide_evidence->getRetentionTime());
   _output_stream->writeAttribute(
     "eng",
@@ -658,7 +768,7 @@ Xpip::writePeptideEvidence(const PeptideEvidence *p_peptide_evidence)
       _output_stream->writeAttribute("checked", "false");
     }
 
-  qDebug() << "Xpip::writePeptideEvidence getParamList";
+  qDebug() << "getParamList";
   const std::map<PeptideEvidenceParam, QVariant> &params =
     p_peptide_evidence->getParamList();
 
@@ -674,7 +784,7 @@ Xpip::writePeptideEvidence(const PeptideEvidence *p_peptide_evidence)
     }
   //   _output_stream->writeEndElement();
   _output_stream->writeEndElement(); // peptide_evidence
-  qDebug() << "Xpip::writePeptideEvidence end";
+  qDebug() << "end";
 }
 
 void
